@@ -1,27 +1,25 @@
 /* glpsol.c */
 
-/*----------------------------------------------------------------------
--- This code is part of GNU Linear Programming Kit (GLPK).
---
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
--- Department for Applied Informatics, Moscow Aviation Institute,
--- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
---
--- GLPK is free software; you can redistribute it and/or modify it
--- under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2, or (at your option)
--- any later version.
---
--- GLPK is distributed in the hope that it will be useful, but WITHOUT
--- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
--- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
--- License for more details.
---
--- You should have received a copy of the GNU General Public License
--- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
--- 02110-1301, USA.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  This code is part of GLPK (GNU Linear Programming Kit).
+*
+*  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
+*  Department for Applied Informatics, Moscow Aviation Institute,
+*  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
+*
+*  GLPK is free software: you can redistribute it and/or modify it
+*  under the terms of the GNU General Public License as published by
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
+*
+*  GLPK is distributed in the hope that it will be useful, but WITHOUT
+*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+*  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+*  License for more details.
+*
+*  You should have received a copy of the GNU General Public License
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
+***********************************************************************/
 
 #include "glpapi.h"
 #include "glpgmp.h"
@@ -131,6 +129,14 @@ static char *out_glp = NULL;
 /* name of output text file, to which the problem should be written in
    GNU LP format; NULL means no GNU LP output */
 
+static char *out_pb = NULL;
+/* name of output text file, to which the problem should be written in
+    OPB format; NULL means no OPB output */
+
+static char *out_npb = NULL;
+/* name of output text file, to which the problem should be written in
+    nomralized OPB format; NULL means no normalized OPB output */
+
 static char *log_file = NULL;
 /* name of output text file, to which a hardcopy of all screen output
    should be written; NULL means no hardcopying */
@@ -268,6 +274,10 @@ static void display_help(char *my_name)
          " format");
       print("   --wtxt filename   write problem to filename in plain te"
          "xt format");
+      print("   --wpb filename    write problem to filename in OPB form"
+         "at");
+      print("   --wnpb filename   write problem to filename in normaliz"
+         "ed OPB format");
       print("   --log filename    write copy of screen output to filena"
          "me");
       print("   -h, --help        display this help information and exi"
@@ -360,7 +370,7 @@ static void display_help(char *my_name)
 -- by the GNU Coding Standards. */
 
 static void display_version(void)
-{     print("GLPSOL---GLPK LP/MIP Solver, Version %s", lib_version());
+{     print("GLPSOL: GLPK LP/MIP Solver, Version %s", lib_version());
       print("");
       print("Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makh"
          "orin,");
@@ -545,6 +555,30 @@ static void parse_cmdline(int argc, char *argv[])
             }
             out_txt = argv[k];
          }
+         else if (p("--wpb"))
+         {  k++;
+            if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
+            {  print("No problem output file specified");
+               exit(EXIT_FAILURE);
+            }
+            if (out_pb != NULL)
+            {  print("Only one OPB output file allowed");
+               exit(EXIT_FAILURE);
+            }
+            out_pb = argv[k];
+         }
+         else if (p("--wnpb"))
+         {  k++;
+            if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
+            {  print("No problem output file specified");
+               exit(EXIT_FAILURE);
+            }
+            if (out_npb != NULL)
+            {  print("Only one normalized OPB output file allowed");
+               exit(EXIT_FAILURE);
+            }
+            out_npb = argv[k];
+         }
          else if (p("--log"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
@@ -686,12 +720,11 @@ int main(int argc, char *argv[])
 {     LPX *lp;
       MPL *mpl = NULL;
       int ret;
-      ulong_t start;
+      glp_ulong start;
       /* parse command line parameters */
       parse_cmdline(argc, argv);
       /* set available memory limit */
-      if (memlim >= 0)
-         lib_mem_limit(ulmul(ulset(0, 1048576), ulset(0, memlim)));
+      if (memlim >= 0) glp_mem_limit(memlim);
       /* remove all output files specified in the command line */
       if (display != NULL) remove(display);
       if (out_bas != NULL) remove(out_bas);
@@ -820,6 +853,22 @@ err:        {  print("Model processing error");
             exit(EXIT_FAILURE);
          }
       }
+      /* write problem in OPB format (if required) */
+      if (out_pb != NULL)
+      {  ret = lpx_write_pb(lp, out_pb, 0);
+         if (ret != 0)
+         {  print("Unable to write problem in OPB format");
+            exit(EXIT_FAILURE);
+         }
+      }
+      /* write problem in normalized OPB format (if required) */
+      if (out_npb != NULL)
+      {  ret = lpx_write_pb(lp, out_npb, 1);
+         if (ret != 0)
+         {  print("Unable to write problem in normalized OPB format");
+            exit(EXIT_FAILURE);
+         }
+      }
       /* if only data check is required, skip computations */
       if (check) goto skip;
       /* scale the problem data (if required) */
@@ -917,7 +966,7 @@ nobs:    ;
       }
       /* display statistics */
       print("Time used:   %.1f secs", xdifftime(xtime(), start));
-      {  ulong_t tpeak;
+      {  glp_ulong tpeak;
          char buf[50];
          lib_mem_usage(NULL, NULL, NULL, &tpeak);
          print("Memory used: %.1f Mb (%s bytes)",
@@ -1007,7 +1056,7 @@ skip: /* delete the problem object */
       if (log_file != NULL) lib_close_log();
       /* check that no memory blocks are still allocated */
       {  int count;
-         ulong_t total;
+         glp_ulong total;
          lib_mem_usage(&count, NULL, &total, NULL);
          xassert(count == 0);
          xassert(total.lo == 0 && total.hi == 0);
