@@ -1,16 +1,16 @@
 /* glpapi.h (application program interface) */
 
 /***********************************************************************
-*  This code is part of GNU Linear Programming Kit (GLPK).
+*  This code is part of GLPK (GNU Linear Programming Kit).
 *
 *  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 *  Department for Applied Informatics, Moscow Aviation Institute,
 *  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 *
-*  GLPK is free software; you can redistribute it and/or modify it
+*  GLPK is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by
-*  the Free Software Foundation; either version 2, or (at your option)
-*  any later version.
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
 *
 *  GLPK is distributed in the hope that it will be useful, but WITHOUT
 *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -18,24 +18,24 @@
 *  License for more details.
 *
 *  You should have received a copy of the GNU General Public License
-*  along with GLPK; see the file COPYING. If not, write to the Free
-*  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-*  02110-1301, USA.
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
 #ifndef _GLPAPI_H
 #define _GLPAPI_H
 
-#include "glpbfi.h"
-
-#ifdef _GLPAPI_PRIVATE
 #include "glpavl.h"
+#include "glpbfd.h"
 #include "glpscs.h"
 
+#define _GLP_PROB
+#define _GLP_BFCP
+
 typedef struct glp_prob glp_prob;
 typedef struct GLPROW GLPROW;
 typedef struct GLPCOL GLPCOL;
 typedef struct GLPAIJ GLPAIJ;
+typedef struct glp_bfcp glp_bfcp;
 
 struct glp_prob
 {     /* LP/MIP problem object */
@@ -70,11 +70,9 @@ struct glp_prob
       int nnz;
       /* number of non-zero constraint coefficients, nnz >= 0 */
       GLPROW **row; /* GLPROW *row[1+m_max]; */
-      /* row[0] is not used;
-         row[i], 1 <= i <= m, is a pointer to i-th row */
+      /* row[i], 1 <= i <= m, is a pointer to i-th row */
       GLPCOL **col; /* GLPCOL *col[1+n_max]; */
-      /* col[0] is not used;
-         col[j], 1 <= j <= n, is a pointer to j-th column */
+      /* col[j], 1 <= j <= n, is a pointer to j-th column */
       AVL *r_tree;
       /* row index to find rows by their names; NULL means this index
          does not exist */
@@ -82,18 +80,18 @@ struct glp_prob
       /* column index to find columns by their names; NULL means this
          index does not exist */
       /*--------------------------------------------------------------*/
-      /* basis factorization */
+      /* basis factorization (LP) */
       int valid;
-      /* this flag is set iff the basis factorization is valid */
-      int *basis; /* int basis[1+m_max]; */
+      /* the factorization is valid only if this flag is set */
+      int *bhead; /* int bhead[1+m_max]; */
       /* basis header (valid only if the factorization is valid);
-         basis[0] is not used;
-         basis[i] = k is the ordinal number of auxiliary (1 <= k <= m)
+         bhead[i] = k is the ordinal number of auxiliary (1 <= k <= m)
          or structural (m+1 <= k <= m+n) variable which corresponds to
          i-th basic variable xB[i], 1 <= i <= m */
-      BFI *binv; /* BFI binv[1:m,1:m]; */
-      /* current basis factorization; NULL means the factorization does
-         not exist */
+      glp_bfcp *bfcp;
+      /* basis factorization control parameters; may be NULL */
+      BFD *bfd; /* BFD bfd[1:m,1:m]; */
+      /* basis factorization driver; may be NULL */
       /*--------------------------------------------------------------*/
       /* basic solution (LP) */
       int pbs_stat;
@@ -110,6 +108,9 @@ struct glp_prob
          GLP_NOFEAS - no dual feasible solution exists */
       double obj_val;
       /* objective function value */
+      int it_cnt;
+      /* simplex method iteration count; increased by one on performing
+         one simplex iteration */
       int some;
       /* ordinal number of some auxiliary or structural variable having
          certain property, 0 <= some <= m+n */
@@ -170,7 +171,7 @@ struct GLPROW
          GLP_NF - non-basic free variable
          GLP_NS - non-basic fixed variable */
       int bind;
-      /* if the auxiliary variable is basic, basis[bind] refers to this
+      /* if the auxiliary variable is basic, bhead[bind] refers to this
          row, otherwise, bind is 0; this attribute is valid only if the
          basis factorization is valid */
       double prim; /* non-scaled */
@@ -228,7 +229,7 @@ struct GLPCOL
          GLP_NF - non-basic free variable
          GLP_NS - non-basic fixed variable */
       int bind;
-      /* if the structural variable is basic, basis[bind] refers to
+      /* if the structural variable is basic, bhead[bind] refers to
          this column; otherwise, bind is 0; this attribute is valid only
          if the basis factorization is valid */
       double prim; /* non-scaled */
@@ -260,13 +261,11 @@ struct GLPAIJ
       GLPAIJ *c_next;
       /* pointer to next coefficient in the same column */
 };
-#endif
 
 #include "glpk.h"
 
 /**********************************************************************/
 
-#ifdef _GLPAPI_PRIVATE
 struct LPXCPS
 {     /* control parameters and statistics */
       int msg_lev;
@@ -327,9 +326,6 @@ struct LPXCPS
          decreased by one each time when one simplex iteration has been
          performed, and reaching zero value signals the solver to stop
          the search; negative value means no iterations limit */
-      int it_cnt;
-      /* simplex iterations count; this count is increased by one each
-         time when one simplex iteration has been performed */
       double tm_lim;
       /* searching time limit, in seconds; if this value is positive,
          it is decreased each time when one simplex iteration has been
@@ -407,30 +403,12 @@ struct LPXCPS
          LPX_C_CLIQUE - clique cuts
          LPX_C_GOMORY - Gomory's mixed integer cuts
          LPX_C_ALL    - all cuts */
-      int bf_type; /* lpx_simplex */
-      /* type of LP basis factorization used:
-         1 - LU + Forrest-Tomlin update
-         2 - LU + Schur complement + Bartels-Golub update
-         3 - LU + Schur complement + Givens rotation update */
 };
-#endif
-
-/* basis status: */
-#define LPX_B_UNDEF     130   /* current basis is undefined */
-#define LPX_B_VALID     131   /* current basis is valid */
 
 #define lpx_order_matrix _glp_lpx_order_matrix
 void lpx_order_matrix(LPX *lp);
 /* order rows and columns of the constraint matrix */
 
-#define lpx_set_rii _glp_lpx_set_rii
-void lpx_set_rii(LPX *lp, int i, double rii);
-/* set (change) row scale factor */
-
-#define lpx_set_sjj _glp_lpx_set_sjj
-void lpx_set_sjj(LPX *lp, int j, double sjj);
-/* set (change) column scale factor */
-
 void glp_put_solution(glp_prob *lp, int inval, const int *p_stat,
       const int *d_stat, const double *obj_val, const int r_stat[],
       const double r_prim[], const double r_dual[], const int c_stat[],
@@ -438,7 +416,7 @@ void glp_put_solution(glp_prob *lp, int inval, const int *p_stat,
 /* store basic solution components */
 
 #define lpx_put_lp_basis _glp_lpx_put_lp_basis
-void lpx_put_lp_basis(LPX *lp, int b_stat, int basis[], BFI *b_inv);
+void lpx_put_lp_basis(LPX *lp, int b_stat, int basis[], BFD *b_inv);
 /* store LP basis information */
 
 #define lpx_put_ray_info _glp_lpx_put_ray_info
@@ -455,45 +433,8 @@ void lpx_put_mip_soln(LPX *lp, int i_stat, double row_mipx[],
       double col_mipx[]);
 /* store mixed integer solution components */
 
-#define lpx_get_rii _glp_lpx_get_rii
-double lpx_get_rii(LPX *lp, int i);
-/* retrieve row scale factor */
-
-#define lpx_get_sjj _glp_lpx_get_sjj
-double lpx_get_sjj(LPX *lp, int j);
-/* retrieve column scale factor */
-
-#define lpx_is_b_avail _glp_lpx_is_b_avail
-int lpx_is_b_avail(LPX *lp);
-/* check if LP basis is available */
-
-#define lpx_get_b_info _glp_lpx_get_b_info
-int lpx_get_b_info(LPX *lp, int i);
-/* retrieve LP basis information */
-
-#define lpx_get_row_b_ind _glp_lpx_get_row_b_ind
-int lpx_get_row_b_ind(LPX *lp, int i);
-/* retrieve row index in LP basis */
-
-#define lpx_get_col_b_ind _glp_lpx_get_col_b_ind
-int lpx_get_col_b_ind(LPX *lp, int j);
-/* retrieve column index in LP basis */
-
-#define lpx_access_inv _glp_lpx_access_inv
-BFI *lpx_access_inv(LPX *lp);
-/* access factorization of basis matrix */
-
-#define lpx_invert _glp_lpx_invert
-int lpx_invert(LPX *lp);
-/* compute factorization of basis matrix */
-
-#define lpx_ftran _glp_lpx_ftran
-void lpx_ftran(LPX *lp, double x[]);
-/* forward transformation (solve system B*x = b) */
-
-#define lpx_btran _glp_lpx_btran
-void lpx_btran(LPX *lp, double x[]);
-/* backward transformation (solve system B'*x = b) */
+BFD *_glp_access_bfd(glp_prob *lp);
+/* access the basis factorization object */
 
 #define lpx_eval_b_prim _glp_lpx_eval_b_prim
 void lpx_eval_b_prim(LPX *lp, double row_prim[], double col_prim[]);
