@@ -1,16 +1,16 @@
 /* glpavl.h (binary search tree) */
 
 /***********************************************************************
-*  This code is part of GNU Linear Programming Kit (GLPK).
+*  This code is part of GLPK (GNU Linear Programming Kit).
 *
 *  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 *  Department for Applied Informatics, Moscow Aviation Institute,
 *  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 *
-*  GLPK is free software; you can redistribute it and/or modify it
+*  GLPK is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by
-*  the Free Software Foundation; either version 2, or (at your option)
-*  any later version.
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
 *
 *  GLPK is distributed in the hope that it will be useful, but WITHOUT
 *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -18,15 +18,12 @@
 *  License for more details.
 *
 *  You should have received a copy of the GNU General Public License
-*  along with GLPK; see the file COPYING. If not, write to the Free
-*  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-*  02110-1301, USA.
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
 #ifndef _GLPAVL_H
 #define _GLPAVL_H
 
-#ifdef _GLPAVL_PRIVATE
 #include "glpdmp.h"
 
 typedef struct AVL AVL;
@@ -78,10 +75,6 @@ struct AVLNODE
       AVLNODE *right;
       /* pointer to the root of the right subtree */
 };
-#else
-typedef struct { double _tree; } AVL;
-typedef struct { double _node; } AVLNODE;
-#endif
 
 #define avl_create_tree _glp_avl_create_tree
 AVL *avl_create_tree(int (*fcmp)(void *info, const void *key1,
