@@ -1,16 +1,16 @@
 /* glplib.h (low-level library routines) */
 
 /***********************************************************************
-*  This code is part of GNU Linear Programming Kit (GLPK).
+*  This code is part of GLPK (GNU Linear Programming Kit).
 *
 *  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 *  Department for Applied Informatics, Moscow Aviation Institute,
 *  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 *
-*  GLPK is free software; you can redistribute it and/or modify it
+*  GLPK is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by
-*  the Free Software Foundation; either version 2, or (at your option)
-*  any later version.
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
 *
 *  GLPK is distributed in the hope that it will be useful, but WITHOUT
 *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -18,9 +18,7 @@
 *  License for more details.
 *
 *  You should have received a copy of the GNU General Public License
-*  along with GLPK; see the file COPYING. If not, write to the Free
-*  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-*  02110-1301, USA.
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
 #ifndef _GLPLIB_H
@@ -45,43 +43,43 @@ void bigmul(int n, int m, unsigned short x[], unsigned short y[]);
 void bigdiv(int n, int m, unsigned short x[], unsigned short y[]);
 /* divide unsigned integer numbers of arbitrary precision */
 
-#define ulong_t _glp_lib_ulong_t
-typedef struct { unsigned int lo, hi; } ulong_t;
+#ifndef _GLP_ULONG
+#define _GLP_ULONG
+typedef struct { unsigned int lo, hi; } glp_ulong;
 /* 64-bit unsigned integer data type */
+#endif
 
-#define uldiv_t _glp_lib_uldiv_t
-typedef struct { ulong_t quot, rem; } uldiv_t;
+typedef struct { glp_ulong quot, rem; } glp_uldiv;
 /* result of 64-bit unsigned integer division */
 
 #define ulset _glp_lib_ulset
-ulong_t ulset(unsigned int hi, unsigned int lo);
+glp_ulong ulset(unsigned int hi, unsigned int lo);
 /* construct an unsigned long integer */
 
 #define uladd _glp_lib_uladd
-ulong_t uladd(ulong_t x, ulong_t y);
+glp_ulong uladd(glp_ulong x, glp_ulong y);
 /* add unsigned long integers */
 
 #define ulsub _glp_lib_ulsub
-ulong_t ulsub(ulong_t x, ulong_t y);
+glp_ulong ulsub(glp_ulong x, glp_ulong y);
 /* subtract unsigned long integers */
 
 #define ulcmp _glp_lib_ulcmp
-int ulcmp(ulong_t x, ulong_t y);
+int ulcmp(glp_ulong x, glp_ulong y);
 /* compare unsigned long integers */
 
 #define ulmul _glp_lib_ulmul
-ulong_t ulmul(ulong_t x, ulong_t y);
+glp_ulong ulmul(glp_ulong x, glp_ulong y);
 /* multiply unsigned long integers */
 
 #define uldiv _glp_lib_uldiv
-uldiv_t uldiv(ulong_t x, ulong_t y);
+glp_uldiv uldiv(glp_ulong x, glp_ulong y);
 /* divide unsigned long integers */
 
 #define ultoa _glp_lib_ultoa
-char *ultoa(ulong_t x, char *s, int radix);
+char *ultoa(glp_ulong x, char *s, int radix);
 /* convert unsigned long integer to character string */
 
-#ifdef _GLPLIB_PRIVATE
 #define lib_set_ptr _glp_lib_set_ptr
 void lib_set_ptr(void *ptr);
 /* store global pointer in TLS */
@@ -89,9 +87,7 @@ void lib_set_ptr(void *ptr);
 #define lib_get_ptr _glp_lib_get_ptr
 void *lib_get_ptr(void);
 /* retrieve global pointer from TLS */
-#endif
 
-#ifdef _GLPLIB_PRIVATE
 typedef struct LIBENV LIBENV;
 typedef struct LIBMEM LIBMEM;
 
@@ -104,7 +100,7 @@ struct LIBENV
       /* version string returned by the routine glp_version */
       /*--------------------------------------------------------------*/
       /* memory allocation */
-      ulong_t mem_limit;
+      glp_ulong mem_limit;
       /* maximal amount of memory (in bytes) available for dynamic
          allocation */
       LIBMEM *mem_ptr;
@@ -113,10 +109,10 @@ struct LIBENV
       /* total number of currently allocated memory blocks */
       int mem_cpeak;
       /* peak value of mem_count */
-      ulong_t mem_total;
+      glp_ulong mem_total;
       /* total amount of currently allocated memory (in bytes; is the
          sum of the size field over all memory block descriptors) */
-      ulong_t mem_tpeak;
+      glp_ulong mem_tpeak;
       /* peak value of mem_total */
       /*--------------------------------------------------------------*/
       /* terminal output */
@@ -148,17 +144,14 @@ struct LIBMEM
       LIBMEM *next;
       /* pointer to next memory block descriptor */
 };
-#endif
 
 #define lib_init_env _glp_lib_init_env
 int lib_init_env(void);
 /* initialize library environment */
 
-#ifdef _GLPLIB_PRIVATE
 #define lib_link_env _glp_lib_link_env
 LIBENV *lib_link_env(void);
 /* retrieve pointer to library environmental block */
-#endif
 
 #define lib_version _glp_lib_version
 const char *lib_version(void);
@@ -229,12 +222,12 @@ void xfree(void *ptr);
 /* free memory block */
 
 #define lib_mem_limit _glp_lib_mem_limit
-void lib_mem_limit(ulong_t limit);
+void lib_mem_limit(glp_ulong limit);
 /* set memory allocation limit */
 
 #define lib_mem_usage _glp_lib_mem_usage
-void lib_mem_usage(int *count, int *cpeak, ulong_t *total,
-      ulong_t *tpeak);
+void lib_mem_usage(int *count, int *cpeak, glp_ulong *total,
+      glp_ulong *tpeak);
 /* get memory usage information */
 
 #define xfopen _glp_lib_xfopen
@@ -254,11 +247,11 @@ int lib_close_log(void);
 /* close hardcopy file */
 
 #define xtime _glp_lib_xtime
-ulong_t xtime(void);
+glp_ulong xtime(void);
 /* determine the current universal time */
 
 #define xdifftime _glp_lib_xdifftime
-double xdifftime(ulong_t t1, ulong_t t0);
+double xdifftime(glp_ulong t1, glp_ulong t0);
 /* compute the difference between two time values */
 
 #define str2int _glp_lib_str2int
