@@ -1,32 +1,29 @@
 /* glprng.h (pseudo-random number generator) */
 
 /***********************************************************************
-*  This code is part of GNU Linear Programming Kit (GLPK).
-* 
+*  This code is part of GLPK (GNU Linear Programming Kit).
+*
 *  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 *  Department for Applied Informatics, Moscow Aviation Institute,
 *  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
-* 
-*  GLPK is free software; you can redistribute it and/or modify it
+*
+*  GLPK is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by
-*  the Free Software Foundation; either version 2, or (at your option)
-*  any later version.
-* 
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
+*
 *  GLPK is distributed in the hope that it will be useful, but WITHOUT
 *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 *  License for more details.
-* 
+*
 *  You should have received a copy of the GNU General Public License
-*  along with GLPK; see the file COPYING. If not, write to the Free
-*  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-*  02110-1301, USA.
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
 #ifndef _GLPRNG_H
 #define _GLPRNG_H
 
-#ifdef _GLPRNG_PRIVATE
 typedef struct RNG RNG;
 
 struct RNG
@@ -36,9 +33,6 @@ struct RNG
       int *fptr;
       /* the next A value to be exported */
 };
-#else
-typedef struct { double _rng; } RNG;
-#endif
 
 #define rng_create_rand _glp_rng_create_rand
 RNG *rng_create_rand(void);
