@@ -1,32 +1,30 @@
 /* glpspx.h (simplex method) */
 
-/*----------------------------------------------------------------------
--- This code is part of GNU Linear Programming Kit (GLPK).
---
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
--- Department for Applied Informatics, Moscow Aviation Institute,
--- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
---
--- GLPK is free software; you can redistribute it and/or modify it
--- under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2, or (at your option)
--- any later version.
---
--- GLPK is distributed in the hope that it will be useful, but WITHOUT
--- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
--- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
--- License for more details.
---
--- You should have received a copy of the GNU General Public License
--- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
--- 02110-1301, USA.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  This code is part of GLPK (GNU Linear Programming Kit).
+*
+*  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
+*  Department for Applied Informatics, Moscow Aviation Institute,
+*  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
+*
+*  GLPK is free software: you can redistribute it and/or modify it
+*  under the terms of the GNU General Public License as published by
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
+*
+*  GLPK is distributed in the hope that it will be useful, but WITHOUT
+*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+*  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+*  License for more details.
+*
+*  You should have received a copy of the GNU General Public License
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
+***********************************************************************/
 
 #ifndef _GLPSPX_H
 #define _GLPSPX_H
 
-#include "glpapi.h"
+#include "glpbfd.h"
 
 typedef struct SPX SPX;
 
@@ -35,35 +33,32 @@ struct SPX
       /*--------------------------------------------------------------*/
       /* LP problem data */
       int m;
-      /* number of rows (auxiliary variables) */
+      /* number of rows (auxiliary variables), m > 0 */
       int n;
-      /* number of columns (structural variables) */
-      int *typx; /* int typx[1+m+n]; */
-      /* typx[0] is not used;
-         typx[k], 1 <= k <= m+n, is the type of the variable x[k]: */
-#define LPX_FR          110   /* free variable:  -inf <  x[k] < +inf  */
-#define LPX_LO          111   /* lower bound:    l[k] <= x[k] < +inf  */
-#define LPX_UP          112   /* upper bound:    -inf <  x[k] <= u[k] */
-#define LPX_DB          113   /* double bound:   l[k] <= x[k] <= u[k] */
-#define LPX_FX          114   /* fixed variable: l[k]  = x[k]  = u[k] */
+      /* number of columns (structural variables), n > 0 */
+      int *type; /* int type[1+m+n]; */
+      /* type[k], 1 <= k <= m+n, is the type of variable x[k]:
+         GLP_FR - free variable
+         GLP_LO - variable with lower bound
+         GLP_UP - variable with upper bound
+         GLP_DB - double-bounded variable
+         GLP_FX - fixed variable */
       double *lb; /* double lb[1+m+n]; */
-      /* lb[0] is not used;
-         lb[k], 1 <= k <= m+n, is an lower bound of the variable x[k];
+      /* lb[k], 1 <= k <= m+n, is an lower bound of variable x[k];
          if x[k] has no lower bound, lb[k] is zero */
       double *ub; /* double ub[1+m+n]; */
-      /* ub[0] is not used;
-         ub[k], 1 <= k <= m+n, is an upper bound of the variable x[k];
-         if x[k] has no upper bound, ub[k] is zero; if x[k] is of fixed
-         type, ub[k] is equal to lb[k] */
+      /* ub[k], 1 <= k <= m+n, is an upper bound of variable x[k];
+         if x[k] has no upper bound, ub[k] is zero;
+         if x[k] is of fixed type, ub[k] is equal to lb[k] */
       int dir;
-      /* optimization direction (sense of the objective function): */
-#define LPX_MIN         120   /* minimization */
-#define LPX_MAX         121   /* maximization */
+      /* optimization direction flag (objective "sense"):
+         GLP_MIN - minimization
+         GLP_MAX - maximization */
       double *coef; /* double coef[1+m+n]; */
       /* coef[0] is a constant term of the objective function;
          coef[k], 1 <= k <= m+n, is a coefficient of the objective
-         function at the variable x[k] (note that auxiliary variables
-         also may have non-zero objective coefficients) */
+         function at variable x[k] (note that auxiliary variables also
+         may have non-zero objective coefficients) */
       /*--------------------------------------------------------------*/
       /* constraint matrix (has m rows and n columns) */
       int *A_ptr; /* int A_ptr[1+m+1]; */
@@ -74,54 +69,47 @@ struct SPX
       int *AT_ind; /* int AT_ind[AT_ptr[n+1]]; */
       double *AT_val; /* double AT_val[AT_ptr[n+1]]; */
       /* constraint matrix in storage-by-columns format */
+      double *col; /* double col[1+m]; */
+      /* working array */
       /*--------------------------------------------------------------*/
-      /* basic solution */
-      int b_stat;
-      /* status of the current basis: */
-#if 0
-#define LPX_B_UNDEF     130   /* current basis is undefined */
-#define LPX_B_VALID     131   /* current basis is valid */
-#endif
-      int p_stat;
-      /* status of the primal solution: */
-#define LPX_P_UNDEF     132   /* primal status is undefined */
-#define LPX_P_FEAS      133   /* solution is primal feasible */
-#define LPX_P_INFEAS    134   /* solution is primal infeasible */
-#define LPX_P_NOFEAS    135   /* no primal feasible solution exists */
-      int d_stat;
-      /* status of the dual solution: */
-#define LPX_D_UNDEF     136   /* dual status is undefined */
-#define LPX_D_FEAS      137   /* solution is dual feasible */
-#define LPX_D_INFEAS    138   /* solution is dual infeasible */
-#define LPX_D_NOFEAS    139   /* no dual feasible solution exists */
-      int *tagx; /* int tagx[1+m+n]; */
-      /* tagx[0] is not used;
-         tagx[k], 1 <= k <= m+n, is the status of the variable x[k]
-         (contents of this array is always defined independently on the
-         status of the current basis): */
-#define LPX_BS          140   /* basic variable */
-#define LPX_NL          141   /* non-basic variable on lower bound */
-#define LPX_NU          142   /* non-basic variable on upper bound */
-#define LPX_NF          143   /* non-basic free variable */
-#define LPX_NS          144   /* non-basic fixed variable */
+      /* basis factorization */
+      int valid;
+      /* the factorization is valid only if this flag is set */
       int *posx; /* int posx[1+m+n]; */
-      /* posx[0] is not used;
-         posx[k], 1 <= k <= m+n, is the position of the variable x[k]
-         in the vector of basic variables xB or non-basic variables xN:
+      /* posx[k], 1 <= k <= m+n, is the position of variable x[k] in
+         the vector of basic variables xB or non-basic variables xN:
          posx[k] = i   means that x[k] = xB[i], 1 <= i <= m
          posx[k] = m+j means that x[k] = xN[j], 1 <= j <= n
-         (if the current basis is undefined, contents of this array is
-         undefined) */
+         (valid only if the basis factorization is valid) */
       int *indx; /* int indx[1+m+n]; */
-      /* indx[0] is not used;
-         indx[i], 1 <= i <= m, is the original number of the basic
-         variable xB[i], i.e. indx[i] = k means that posx[k] = i
-         indx[m+j], 1 <= j <= n, is the original number of the non-basic
+      /* indx[i], 1 <= i <= m, is the original number of basic variable
+         xB[i], i.e. indx[i] = k means that posx[k] = i
+         indx[m+j], 1 <= j <= n, is the original number of non-basic
          variable xN[j], i.e. indx[m+j] = k means that posx[k] = m+j
-         (if the current basis is undefined, contents of this array is
-         undefined) */
-      BFI *inv; /* BFI inv[1:m,1:m]; */
-      /* an invertable (factorized) form of the current basis matrix */
+         (valid only if the basis factorization is valid) */
+      BFD *bfd; /* BFD bfd[1:m,1:m]; */
+      /* basis factorization driver */
+      /*--------------------------------------------------------------*/
+      /* basic solution */
+      int p_stat;
+      /* primal basic solution status:
+         GLP_UNDEF  - primal solution is undefined
+         GLP_FEAS   - primal solution is feasible
+         GLP_INFEAS - primal solution is infeasible
+         GLP_NOFEAS - no primal feasible solution exists */
+      int d_stat;
+      /* dual basic solution status:
+         GLP_UNDEF  - dual solution is undefined
+         GLP_FEAS   - dual solution is feasible
+         GLP_INFEAS - dual solution is infeasible
+         GLP_NOFEAS - no dual feasible solution exists */
+      int *stat; /* int stat[1+m+n]; */
+      /* stat[k], 1 <= k <= m+n, is the status of variable x[k]:
+         GLP_BS - basic variable
+         GLP_NL - non-basic variable on lower bound
+         GLP_NU - non-basic variable on upper bound
+         GLP_NF - non-basic free variable
+         GLP_NS - non-basic fixed variable */
       double *bbar; /* double bbar[1+m]; */
       /* bbar[0] is not used;
          bbar[i], 1 <= i <= m, is a value of basic variable xB[i] */
@@ -256,7 +244,7 @@ struct SPX
          gets zero, the reference space is automatically redefined */
       double *work; /* double work[1+m+n]; */
       /* working array (used for various purposes) */
-      int *orig_typx; /* orig_typx[1+m+n]; */
+      int *orig_type; /* orig_type[1+m+n]; */
       /* is used to save the original types of variables */
       double *orig_lb; /* orig_lb[1+m+n]; */
       /* is used to save the original lower bounds of variables */
@@ -310,7 +298,7 @@ struct SPX
 int spx_invert(SPX *spx);
 /* reinvert the basis matrix */
 
-void spx_ftran(SPX *spx, double x[], int save);
+void spx_ftran(SPX *spx, double x[]);
 /* perform forward transformation (FTRAN) */
 
 void spx_btran(SPX *spx, double x[]);
@@ -399,7 +387,7 @@ double spx_err_in_dvec(SPX *spx);
 
 /* simplex method solver routines ------------------------------------*/
 
-int spx_warm_up(SPX *spx);
+void spx_warm_up(SPX *spx);
 /* "warm up" the initial basis */
 
 int spx_prim_opt(SPX *spx);
