@@ -1,16 +1,16 @@
 /* glpapi01.c (problem creating and modifying routines) */
 
 /***********************************************************************
-*  This code is part of GNU Linear Programming Kit (GLPK).
+*  This code is part of GLPK (GNU Linear Programming Kit).
 *
 *  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 *  Department for Applied Informatics, Moscow Aviation Institute,
 *  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 *
-*  GLPK is free software; you can redistribute it and/or modify it
+*  GLPK is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by
-*  the Free Software Foundation; either version 2, or (at your option)
-*  any later version.
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
 *
 *  GLPK is distributed in the hope that it will be useful, but WITHOUT
 *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -18,12 +18,9 @@
 *  License for more details.
 *
 *  You should have received a copy of the GNU General Public License
-*  along with GLPK; see the file COPYING. If not, write to the Free
-*  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-*  02110-1301, USA.
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
-#define _GLPAPI_PRIVATE
 #include "glpapi.h"
 
 /* CAUTION: DO NOT CHANGE THE LIMITS BELOW */
@@ -77,11 +74,13 @@ glp_prob *glp_create_prob(void)
       lp->r_tree = lp->c_tree = NULL;
       /* basis factorization */
       lp->valid = 0;
-      lp->basis = xcalloc(1+lp->m_max, sizeof(int));
-      lp->binv = NULL;
+      lp->bhead = xcalloc(1+lp->m_max, sizeof(int));
+      lp->bfcp = NULL;
+      lp->bfd = NULL;
       /* basic solution (LP) */
       lp->pbs_stat = lp->dbs_stat = GLP_UNDEF;
       lp->obj_val = 0.0;
+      lp->it_cnt = 0;
       lp->some = 0;
       /* interior-point solution (LP) */
       lp->ipt_stat = GLP_UNDEF;
@@ -229,8 +228,8 @@ int glp_add_rows(glp_prob *lp, int nrs)
          memcpy(&lp->row[1], &save[1], lp->m * sizeof(GLPROW *));
          xfree(save);
          /* do not forget about the basis header */
-         xfree(lp->basis);
-         lp->basis = xcalloc(1+lp->m_max, sizeof(int));
+         xfree(lp->bhead);
+         lp->bhead = xcalloc(1+lp->m_max, sizeof(int));
       }
       /* add new rows to the end of the row list */
       for (i = lp->m+1; i <= m_new; i++)
@@ -1105,6 +1104,18 @@ void glp_del_cols(glp_prob *lp, int ncs, const int num[])
       }
       /* set new number of columns */
       lp->n = n_new;
+      /* if the basis header is still valid, adjust it */
+      if (lp->valid)
+      {  int m = lp->m;
+         int *bhead = lp->bhead;
+         for (j = 1; j <= n_new; j++)
+         {  k = lp->col[j]->bind;
+            if (k != 0)
+            {  xassert(1 <= k && k <= m);
+               bhead[k] = m + j;
+            }
+         }
+      }
       return;
 }
 
@@ -1130,8 +1141,9 @@ void glp_delete_prob(glp_prob *lp)
       xfree(lp->col);
       if (lp->r_tree != NULL) avl_delete_tree(lp->r_tree);
       if (lp->c_tree != NULL) avl_delete_tree(lp->c_tree);
-      xfree(lp->basis);
-      if (lp->binv != NULL) bfi_delete_binv(lp->binv);
+      xfree(lp->bhead);
+      if (lp->bfcp != NULL) xfree(lp->bfcp);
+      if (lp->bfd != NULL) bfd_delete_it(lp->bfd);
       xfree(lp);
       return;
 }
