@@ -1,16 +1,16 @@
 /* glpdmp.c (dynamic memory pool) */
 
 /***********************************************************************
-*  This code is part of GNU Linear Programming Kit (GLPK).
+*  This code is part of GLPK (GNU Linear Programming Kit).
 *
 *  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 *  Department for Applied Informatics, Moscow Aviation Institute,
 *  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 *
-*  GLPK is free software; you can redistribute it and/or modify it
+*  GLPK is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by
-*  the Free Software Foundation; either version 2, or (at your option)
-*  any later version.
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
 *
 *  GLPK is distributed in the hope that it will be useful, but WITHOUT
 *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -18,15 +18,12 @@
 *  License for more details.
 *
 *  You should have received a copy of the GNU General Public License
-*  along with GLPK; see the file COPYING. If not, write to the Free
-*  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-*  02110-1301, USA.
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
-#define _GLPDMP_PRIVATE
 #include "glpdmp.h"
 
-#define _GLPDMP_DEBUG 1
+#define _GLPDMP_DEBUG 0
 
 #if _GLPDMP_DEBUG
 struct info
@@ -203,7 +200,7 @@ void dmp_free_atom(DMP *pool, void *atom, int size)
 *  SYNOPSIS
 *
 *  #include "glpdmp.h"
-*  ulong_t dmp_in_use(DMP *pool);
+*  glp_ulong dmp_in_use(DMP *pool);
 *
 *  DESCRIPTION
 *
@@ -215,7 +212,7 @@ void dmp_free_atom(DMP *pool, void *atom, int size)
 *
 *  The routine returns the number of atoms which are still in use. */
 
-ulong_t dmp_in_use(DMP *pool)
+glp_ulong dmp_in_use(DMP *pool)
 {     return
          pool->count;
 }
