@@ -1,26 +1,24 @@
 /* glplib02.c (64-bit arithmetic) */
 
 /***********************************************************************
-*  This code is part of GNU Linear Programming Kit (GLPK).
-* 
+*  This code is part of GLPK (GNU Linear Programming Kit).
+*
 *  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 *  Department for Applied Informatics, Moscow Aviation Institute,
 *  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
-* 
-*  GLPK is free software; you can redistribute it and/or modify it
+*
+*  GLPK is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by
-*  the Free Software Foundation; either version 2, or (at your option)
-*  any later version.
-* 
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
+*
 *  GLPK is distributed in the hope that it will be useful, but WITHOUT
 *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 *  License for more details.
-* 
+*
 *  You should have received a copy of the GNU General Public License
-*  along with GLPK; see the file COPYING. If not, write to the Free
-*  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-*  02110-1301, USA.
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
 #include "glplib.h"
@@ -33,14 +31,14 @@
 *  SYNOPSIS
 *
 *  #include "glplib.h"
-*  ulong_t ulset(unsigned int hi, unsigned int lo);
+*  glp_ulong ulset(unsigned int hi, unsigned int lo);
 *
 *  RETURNS
 *
 *  The routine ulset returns the number ((hi << 32) | lo). */
 
-ulong_t ulset(unsigned int hi, unsigned int lo)
-{     ulong_t x;
+glp_ulong ulset(unsigned int hi, unsigned int lo)
+{     glp_ulong x;
       x.lo = lo, x.hi = hi;
       return x;
 }
@@ -53,13 +51,13 @@ ulong_t ulset(unsigned int hi, unsigned int lo)
 *  SYNOPSIS
 *
 *  #include "glplib.h"
-*  ulong_t uladd(ulong_t x, ulong_t y);
+*  glp_ulong uladd(glp_ulong x, glp_ulong y);
 *
 *  RETURNS
 *
 *  The routine uladd returns the sum x + y. */
 
-ulong_t uladd(ulong_t x, ulong_t y)
+glp_ulong uladd(glp_ulong x, glp_ulong y)
 {     if (x.lo <= 0xFFFFFFFF - y.lo)
          x.lo += y.lo, x.hi += y.hi;
       else
@@ -75,13 +73,13 @@ ulong_t uladd(ulong_t x, ulong_t y)
 *  SYNOPSIS
 *
 *  #include "glplib.h"
-*  ulong_t ulsub(ulong_t x, ulong_t y);
+*  glp_ulong ulsub(glp_ulong x, glp_ulong y);
 *
 *  RETURNS
 *
 *  The routine ulsub returns the difference x - y. */
 
-ulong_t ulsub(ulong_t x, ulong_t y)
+glp_ulong ulsub(glp_ulong x, glp_ulong y)
 {     if (x.lo >= y.lo)
          x.lo -= y.lo, x.hi -= y.hi;
       else
@@ -97,13 +95,13 @@ ulong_t ulsub(ulong_t x, ulong_t y)
 *  SYNOPSIS
 *
 *  #include "glplib.h"
-*  int ulcmp(ulong_t x, ulong_t y);
+*  int ulcmp(glp_ulong x, glp_ulong y);
 *
 *  RETURNS
 *
 *  The routine ulcmp returns the sign of the difference x - y. */
 
-int ulcmp(ulong_t x, ulong_t y)
+int ulcmp(glp_ulong x, glp_ulong y)
 {     if (x.hi > y.hi) return +1;
       if (x.hi < y.hi) return -1;
       if (x.lo > y.lo) return +1;
@@ -119,13 +117,13 @@ int ulcmp(ulong_t x, ulong_t y)
 *  SYNOPSIS
 *
 *  #include "glplib.h"
-*  ulong_t ulmul(ulong_t x, ulong_t y);
+*  glp_ulong ulmul(glp_ulong x, glp_ulong y);
 *
 *  RETURNS
 *
 *  The routine ulmul returns the product x * y. */
 
-ulong_t ulmul(ulong_t x, ulong_t y)
+glp_ulong ulmul(glp_ulong x, glp_ulong y)
 {     unsigned short xx[8], yy[4];
       xx[4] = (unsigned short)x.lo;
       xx[5] = (unsigned short)(x.lo >> 16);
@@ -149,18 +147,18 @@ ulong_t ulmul(ulong_t x, ulong_t y)
 *  SYNOPSIS
 *
 *  #include "glplib.h"
-*  uldiv_t uldiv(ulong_t x, ulong_t y);
+*  glp_uldiv uldiv(glp_ulong x, glp_ulong y);
 *
 *  RETURNS
 *
-*  The routine uldiv returns a structure of type uldiv_t.
+*  The routine uldiv returns a structure of type glp_uldiv.
 *
 *  The structure has the following members: quot, which is set to the
 *  quotient x div y, and rem, which is set to the remainder x mod y. */
 
-uldiv_t uldiv(ulong_t x, ulong_t y)
+glp_uldiv uldiv(glp_ulong x, glp_ulong y)
 {     int m;
-      uldiv_t qr;
+      glp_uldiv qr;
       unsigned short xx[8], yy[4];
       xx[0] = (unsigned short)x.lo;
       xx[1] = (unsigned short)(x.lo >> 16);
@@ -202,7 +200,7 @@ uldiv_t uldiv(ulong_t x, ulong_t y)
 *  SYNOPSIS
 *
 *  #include "glplib.h"
-*  char *ultoa(ulong_t x, char *s, int radix);
+*  char *ultoa(glp_ulong x, char *s, int radix);
 *
 *  DESCRIPTION
 *
@@ -221,10 +219,10 @@ uldiv_t uldiv(ulong_t x, ulong_t y)
 *
 *  The routine returns the pointer s. */
 
-char *ultoa(ulong_t x, char *s, int radix)
+char *ultoa(glp_ulong x, char *s, int radix)
 {     static const char *d = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
-      ulong_t base;
-      uldiv_t t;
+      glp_ulong base;
+      glp_uldiv t;
       int len = 0;
       xassert(2 <= radix && radix <= 36);
       base = ulset(0, radix);
@@ -248,8 +246,8 @@ char *ultoa(ulong_t x, char *s, int radix)
 #define N_TEST 1000000
 /* number of tests */
 
-static ulong_t random(RNG *rand)
-{     ulong_t x;
+static glp_ulong random(RNG *rand)
+{     glp_ulong x;
       int k;
       k = rng_unif_rand(rand, 4);
       assert(0 <= k && k <= 3);
@@ -271,8 +269,8 @@ static ulong_t random(RNG *rand)
 
 int main(void)
 {     RNG *rand;
-      ulong_t x, y;
-      uldiv_t z;
+      glp_ulong x, y;
+      glp_uldiv z;
       int test;
       rand = rng_create_rand();
       for (test = 1; test <= N_TEST; test++)
