@@ -1,16 +1,16 @@
 /* glplib06.c (memory allocation) */
 
 /***********************************************************************
-*  This code is part of GNU Linear Programming Kit (GLPK).
+*  This code is part of GLPK (GNU Linear Programming Kit).
 *
 *  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 *  Department for Applied Informatics, Moscow Aviation Institute,
 *  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 *
-*  GLPK is free software; you can redistribute it and/or modify it
+*  GLPK is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by
-*  the Free Software Foundation; either version 2, or (at your option)
-*  any later version.
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
 *
 *  GLPK is distributed in the hope that it will be useful, but WITHOUT
 *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -18,12 +18,9 @@
 *  License for more details.
 *
 *  You should have received a copy of the GNU General Public License
-*  along with GLPK; see the file COPYING. If not, write to the Free
-*  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-*  02110-1301, USA.
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
-#define _GLPLIB_PRIVATE
 #include "glplib.h"
 
 /***********************************************************************
@@ -161,14 +158,14 @@ void xfree(void *ptr)
 *  SYNOPSIS
 *
 *  #include "glplib.h"
-*  void lib_mem_limit(ulong_t limit);
+*  void lib_mem_limit(glp_ulong limit);
 *
 *  DESCRIPTION
 *
 *  The routine lib_mem_limit limits the amount of memory available for
 *  dynamic allocation (in GLPK routines) to limit bytes. */
 
-void lib_mem_limit(ulong_t limit)
+void lib_mem_limit(glp_ulong limit)
 {     LIBENV *env = lib_link_env();
       env->mem_limit = limit;
       return;
@@ -182,8 +179,8 @@ void lib_mem_limit(ulong_t limit)
 *  SYNOPSIS
 *
 *  #include "glplib.h"
-*  void lib_mem_usage(int *count, int *cpeak, ulong_t *total,
-*     ulong_t *tpeak);
+*  void lib_mem_usage(int *count, int *cpeak, glp_ulong *total,
+*     glp_ulong *tpeak);
 *
 *  DESCRIPTION
 *
@@ -206,8 +203,8 @@ void lib_mem_limit(ulong_t limit)
 *  *tpeak is the peak value of *total reached since the initialization
 *  of the GLPK library envirionment. */
 
-void lib_mem_usage(int *count, int *cpeak, ulong_t *total,
-      ulong_t *tpeak)
+void lib_mem_usage(int *count, int *cpeak, glp_ulong *total,
+      glp_ulong *tpeak)
 {     LIBENV *env = lib_link_env();
       if (count != NULL) *count = env->mem_count;
       if (cpeak != NULL) *cpeak = env->mem_cpeak;
