@@ -1,34 +1,36 @@
-/* glplpf.c (LP basis factorization) */
+/* glplpf.c (LP basis factorization, Schur complement version) */
 
-/*----------------------------------------------------------------------
--- This code is part of GNU Linear Programming Kit (GLPK).
---
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
--- Department for Applied Informatics, Moscow Aviation Institute,
--- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
---
--- GLPK is free software; you can redistribute it and/or modify it
--- under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2, or (at your option)
--- any later version.
---
--- GLPK is distributed in the hope that it will be useful, but WITHOUT
--- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
--- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
--- License for more details.
---
--- You should have received a copy of the GNU General Public License
--- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
--- 02110-1301, USA.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  This code is part of GLPK (GNU Linear Programming Kit).
+*
+*  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
+*  Department for Applied Informatics, Moscow Aviation Institute,
+*  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
+*
+*  GLPK is free software: you can redistribute it and/or modify it
+*  under the terms of the GNU General Public License as published by
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
+*
+*  GLPK is distributed in the hope that it will be useful, but WITHOUT
+*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+*  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+*  License for more details.
+*
+*  You should have received a copy of the GNU General Public License
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
+***********************************************************************/
 
-#include "glplib.h"
-#define _GLPLPF_PRIVATE
 #include "glplpf.h"
+#include "glplib.h"
 
 #define _GLPLPF_DEBUG 0
 
+/* CAUTION: DO NOT CHANGE THE LIMIT BELOW */
+
+#define M_MAX 100000000 /* = 100*10^6 */
+/* maximal order of the basis matrix */
+
 /***********************************************************************
 *  NAME
 *
@@ -41,40 +43,35 @@
 *
 *  DESCRIPTION
 *
-*  The routine lpf_create_it creates the LP basis factorization, which
-*  initially corresponds to an empty basis.
+*  The routine lpf_create_it creates a program object, which represents
+*  a factorization of LP basis.
 *
 *  RETURNS
 *
-*  The routine lpf_create_it returns a pointer to the LPF object, which
-*  defines the factorization. */
+*  The routine lpf_create_it returns a pointer to the object created. */
 
 LPF *lpf_create_it(void)
 {     LPF *lpf;
-      int n_max = 50, v_size = 1000;
 #if _GLPLPF_DEBUG
       xprintf("lpf_create_it: warning: debug mode enabled\n");
 #endif
       lpf = xmalloc(sizeof(LPF));
-      lpf->m0 = 0;
-      lpf->luf = NULL;
+      lpf->valid = 0;
+      lpf->m0_max = lpf->m0 = 0;
+      lpf->luf = luf_create_it();
       lpf->m = 0;
       lpf->B = NULL;
-      lpf->n_max = n_max;
+      lpf->n_max = 50;
       lpf->n = 0;
-      lpf->R_ptr = xcalloc(1+n_max, sizeof(int));
-      lpf->R_len = xcalloc(1+n_max, sizeof(int));
-      lpf->S_ptr = xcalloc(1+n_max, sizeof(int));
-      lpf->S_len = xcalloc(1+n_max, sizeof(int));
-      lpf->scf = scf_create_it(n_max);
+      lpf->R_ptr = lpf->R_len = NULL;
+      lpf->S_ptr = lpf->S_len = NULL;
+      lpf->scf = NULL;
       lpf->P_row = lpf->P_col = NULL;
       lpf->Q_row = lpf->Q_col = NULL;
-      lpf->v_size = v_size;
-      lpf->v_ptr = 1;
-      lpf->v_ind = xcalloc(1+v_size, sizeof(int));
-      lpf->v_val = xcalloc(1+v_size, sizeof(double));
-      lpf->saved = 0;
-      lpf->newcol = NULL;
+      lpf->v_size = 1000;
+      lpf->v_ptr = 0;
+      lpf->v_ind = NULL;
+      lpf->v_val = NULL;
       lpf->work1 = lpf->work2 = NULL;
       return lpf;
 }
@@ -87,8 +84,8 @@ LPF *lpf_create_it(void)
 *  SYNOPSIS
 *
 *  #include "glplpf.h"
-*  int lpf_factorize(LPF *lpf, int m, int (*col)(void *info, int j,
-*     int ind[], double val[]), void *info);
+*  int lpf_factorize(LPF *lpf, int m, const int bh[], int (*col)
+*     (void *info, int j, int ind[], double val[]), void *info);
 *
 *  DESCRIPTION
 *
@@ -100,64 +97,92 @@ LPF *lpf_create_it(void)
 *
 *  The parameter m specifies the order of B, m > 0.
 *
-*  The formal routine col specifies the basis matrix B. To obtain j-th
-*  column of B the routine lpf_factorize calls the routine col with the
-*  parameter j (1 <= j <= m). In response the routine col should store
-*  row indices and numerical values of non-zero elements of j-th column
-*  of B to locations rn[1], ..., rn[len] and bj[1], ..., bj[len], resp.,
-*  where len is the number of non-zeros in j-th column, which should be
-*  returned on exit. Neiter zero nor duplicate elements are allowed.
+*  The array bh specifies the basis header: bh[j], 1 <= j <= m, is the
+*  number of j-th column of B in some original matrix. The array bh is
+*  optional and can be specified as NULL.
+*
+*  The formal routine col specifies the matrix B to be factorized. To
+*  obtain j-th column of A the routine lpf_factorize calls the routine
+*  col with the parameter j (1 <= j <= n). In response the routine col
+*  should store row indices and numerical values of non-zero elements
+*  of j-th column of B to locations ind[1,...,len] and val[1,...,len],
+*  respectively, where len is the number of non-zeros in j-th column
+*  returned on exit. Neither zero nor duplicate elements are allowed.
 *
 *  The parameter info is a transit pointer passed to the routine col.
 *
 *  RETURNS
 *
-*  The routine lpf_factorize returns one of the following codes:
+*  0  The factorization has been successfully computed.
 *
-*  0 - no errors;
-*  1 - the specified basis matrix is singular;
-*  2 - the given basis matrix is ill-conditioned.
+*  LPF_ESING
+*     The specified matrix is singular within the working precision.
 *
-*  For more details see comments to the routine luf_decomp. */
+*  LPF_ECOND
+*     The specified matrix is ill-conditioned.
+*
+*  For more details see comments to the routine luf_factorize. */
 
-int lpf_factorize(LPF *lpf, int m, int (*col)(void *info, int j,
-      int ind[], double val[]), void *info)
-{     int n_max = lpf->n_max;
-      int *P_row = lpf->P_row;
-      int *P_col = lpf->P_col;
-      int *Q_row = lpf->Q_row;
-      int *Q_col = lpf->Q_col;
-      int k, ret;
+int lpf_factorize(LPF *lpf, int m, const int bh[], int (*col)
+      (void *info, int j, int ind[], double val[]), void *info)
+{     int k, ret;
 #if _GLPLPF_DEBUG
       int i, j, len, *ind;
       double *B, *val;
 #endif
+      xassert(bh == bh);
       if (m < 1)
          xfault("lpf_factorize: m = %d; invalid parameter\n", m);
-      /* reallocate some objects, if necessary */
-      if (lpf->m0 != m)
-      {  lpf->m0 = m;
-         if (lpf->luf != NULL) luf_delete(lpf->luf);
-         lpf->luf = luf_create(m, 0);
-         if (lpf->P_row != NULL) xfree(lpf->P_row);
-         lpf->P_row = P_row = xcalloc(1+m+n_max, sizeof(int));
+      if (m > M_MAX)
+         xfault("lpf_factorize: m = %d; matrix too big\n", m);
+      lpf->m0 = lpf->m = m;
+      /* invalidate the factorization */
+      lpf->valid = 0;
+      /* allocate/reallocate arrays, if necessary */
+      if (lpf->R_ptr == NULL)
+         lpf->R_ptr = xcalloc(1+lpf->n_max, sizeof(int));
+      if (lpf->R_len == NULL)
+         lpf->R_len = xcalloc(1+lpf->n_max, sizeof(int));
+      if (lpf->S_ptr == NULL)
+         lpf->S_ptr = xcalloc(1+lpf->n_max, sizeof(int));
+      if (lpf->S_len == NULL)
+         lpf->S_len = xcalloc(1+lpf->n_max, sizeof(int));
+      if (lpf->scf == NULL)
+         lpf->scf = scf_create_it(lpf->n_max);
+      if (lpf->v_ind == NULL)
+         lpf->v_ind = xcalloc(1+lpf->v_size, sizeof(int));
+      if (lpf->v_val == NULL)
+         lpf->v_val = xcalloc(1+lpf->v_size, sizeof(double));
+      if (lpf->m0_max < m)
+      {  if (lpf->P_row != NULL) xfree(lpf->P_row);
          if (lpf->P_col != NULL) xfree(lpf->P_col);
-         lpf->P_col = P_col = xcalloc(1+m+n_max, sizeof(int));
          if (lpf->Q_row != NULL) xfree(lpf->Q_row);
-         lpf->Q_row = Q_row = xcalloc(1+m+n_max, sizeof(int));
          if (lpf->Q_col != NULL) xfree(lpf->Q_col);
-         lpf->Q_col = Q_col = xcalloc(1+m+n_max, sizeof(int));
-         if (lpf->newcol != NULL) xfree(lpf->newcol);
-         lpf->newcol = xcalloc(1+m+n_max, sizeof(double));
          if (lpf->work1 != NULL) xfree(lpf->work1);
-         lpf->work1 = xcalloc(1+m+n_max, sizeof(double));
          if (lpf->work2 != NULL) xfree(lpf->work2);
-         lpf->work2 = xcalloc(1+m+n_max, sizeof(double));
+         lpf->m0_max = m + 100;
+         lpf->P_row = xcalloc(1+lpf->m0_max+lpf->n_max, sizeof(int));
+         lpf->P_col = xcalloc(1+lpf->m0_max+lpf->n_max, sizeof(int));
+         lpf->Q_row = xcalloc(1+lpf->m0_max+lpf->n_max, sizeof(int));
+         lpf->Q_col = xcalloc(1+lpf->m0_max+lpf->n_max, sizeof(int));
+         lpf->work1 = xcalloc(1+lpf->m0_max+lpf->n_max, sizeof(double));
+         lpf->work2 = xcalloc(1+lpf->m0_max+lpf->n_max, sizeof(double));
       }
-      /* compute factorization */
-      ret = luf_decomp(lpf->luf, info, col, NULL);
-      /* now B = B0 */
-      lpf->m = m;
+      /* try to factorize the basis matrix */
+      switch (luf_factorize(lpf->luf, m, col, info))
+      {  case 0:
+            break;
+         case LUF_ESING:
+            ret = LPF_ESING;
+            goto done;
+         case LUF_ECOND:
+            ret = LPF_ECOND;
+            goto done;
+         default:
+            xassert(lpf != lpf);
+      }
+      /* the basis matrix has been successfully factorized */
+      lpf->valid = 1;
 #if _GLPLPF_DEBUG
       /* store the basis matrix for debugging */
       if (lpf->B != NULL) xfree(lpf->B);
@@ -181,18 +206,19 @@ int lpf_factorize(LPF *lpf, int m, int (*col)(void *info, int j,
       xfree(ind);
       xfree(val);
 #endif
-      /* B = B0, so no additional rows and columns are needed */
+      /* B = B0, so there are no additional rows/columns */
       lpf->n = 0;
       /* reset the Schur complement factorization */
       scf_reset_it(lpf->scf);
       /* P := Q := I */
       for (k = 1; k <= m; k++)
-         P_row[k] = P_col[k] = Q_row[k] = Q_col[k] = k;
-      /* make all locations in SVA free */
+      {  lpf->P_row[k] = lpf->P_col[k] = k;
+         lpf->Q_row[k] = lpf->Q_col[k] = k;
+      }
+      /* make all SVA locations free */
       lpf->v_ptr = 1;
-      /* reset new column save flag */
-      lpf->saved = 0;
-      /* bring the return code to the calling program */
+      ret = 0;
+done: /* return to the calling program */
       return ret;
 }
 
@@ -353,7 +379,7 @@ static void check_error(LPF *lpf, int tr, const double x[],
       }
       if (dmax > 1e-8)
          xprintf("%s: dmax = %g; relative error too large\n",
-            !tr ? "lpf_do_ftran" : "lpf_do_btran", dmax);
+            !tr ? "lpf_ftran" : "lpf_btran", dmax);
       return;
 }
 #endif
@@ -361,35 +387,22 @@ static void check_error(LPF *lpf, int tr, const double x[],
 /***********************************************************************
 *  NAME
 *
-*  lpf_do_ftran - perform forward transformation (FTRAN)
+*  lpf_ftran - perform forward transformation (solve system B*x = b)
 *
 *  SYNOPSIS
 *
 *  #include "glplpf.h"
-*  void lpf_do_ftran(LPF *lpf, double x[], int save);
+*  void lpf_ftran(LPF *lpf, double x[]);
 *
 *  DESCRIPTION
 *
-*  The routine lpf_do_ftran performs forward transformation (FTRAN) of
-*  a given vector using the basis factorization.
+*  The routine lpf_ftran performs forward transformation, i.e. solves
+*  the system B*x = b, where B is the basis matrix, x is the vector of
+*  unknowns to be computed, b is the vector of right-hand sides.
 *
-*  To perform FTRAN the routine solves the system B * x' = x, where B
-*  is the basis matrix, x' is the vector of unknowns (transformed vector
-*  to be computed), x is the vector of right-hand sides (input vector to
-*  be transformed).
-*
-*  On entry the array x should contain components of the vector x in
-*  locations x[1], x[2], ..., x[m], where m is the order of the basis
-*  matrix. On exit this array will contain components of the vector x'
-*  in the same locations.
-*
-*  The parameter save is a flag. If this flag is set, it means that the
-*  input vector x is a column of the non-basic variable chosen to enter
-*  the basis. In this case the routine saves this column (after partial
-*  transformation), so it can be used on updating the factorization for
-*  the adjacent basis. Note that the simplex method routine should call
-*  this routine with the save flag set at least once before a subsequent
-*  updating the basis.
+*  On entry elements of the vector b should be stored in dense format
+*  in locations x[1], ..., x[m], where m is the number of rows. On exit
+*  the routine stores elements of the vector x in the same locations.
 *
 *  BACKGROUND
 *
@@ -450,7 +463,7 @@ static void check_error(LPF *lpf, int tr, const double x[],
 *     (   ) = Q' (    )
 *     ( y )      ( g2 )                                               */
 
-void lpf_do_ftran(LPF *lpf, double x[], int save)
+void lpf_ftran(LPF *lpf, double x[])
 {     int m0 = lpf->m0;
       int m = lpf->m;
       int n  = lpf->n;
@@ -463,18 +476,14 @@ void lpf_do_ftran(LPF *lpf, double x[], int save)
 #if _GLPLPF_DEBUG
       double *b;
 #endif
+      if (!lpf->valid)
+         xfault("lpf_ftran: the factorization is not valid\n");
       xassert(0 <= m && m <= m0 + n);
 #if _GLPLPF_DEBUG
       /* save the right-hand side vector */
       b = xcalloc(1+m, sizeof(double));
       for (i = 1; i <= m; i++) b[i] = x[i];
 #endif
-      /* save the specified column for further updating */
-      if (save)
-      {  double *newcol = lpf->newcol;
-         lpf->saved = 1;
-         for (i = 1; i <= m; i++) newcol[i] = x[i];
-      }
       /* (f g) := inv(P) * (b 0) */
       for (i = 1; i <= m0 + n; i++)
          fg[i] = ((ii = P_col[i]) <= m ? x[ii] : 0.0);
@@ -501,27 +510,23 @@ void lpf_do_ftran(LPF *lpf, double x[], int save)
 /***********************************************************************
 *  NAME
 *
-*  lpf_do_btran - perform backward transformation (BTRAN)
+*  lpf_btran - perform backward transformation (solve system B'*x = b)
 *
 *  SYNOPSIS
 *
 *  #include "glplpf.h"
-*  void lpf_do_btran(LPF *lpf, double x[]);
+*  void lpf_btran(LPF *lpf, double x[]);
 *
 *  DESCRIPTION
 *
-*  The routine lpf_do_btran performs backward transformation (BTRAN) of
-*  a given vector using the basis factorization.
+*  The routine lpf_btran performs backward transformation, i.e. solves
+*  the system B'*x = b, where B' is a matrix transposed to the basis
+*  matrix B, x is the vector of unknowns to be computed, b is the vector
+*  of right-hand sides.
 *
-*  To perform BTRAN the routine solves the system B * x' = x, where B'
-*  is a matrix transposed to B, B is the basis matrix, x' is the vector
-*  of unknowns (transformed vector to be computed), x is the vector of
-*  right-hand sides (input vector to be transformed).
-*
-*  On entry the array x should contain components of the vector x in
-*  locations x[1], x[2], ..., x[m], where m is the order of the basis
-*  matrix. On exit this array will contain components of the vector x'
-*  in the same locations.
+*  On entry elements of the vector b should be stored in dense format
+*  in locations x[1], ..., x[m], where m is the number of rows. On exit
+*  the routine stores elements of the vector x in the same locations.
 *
 *  BACKGROUND
 *
@@ -588,7 +593,7 @@ void lpf_do_ftran(LPF *lpf, double x[], int save)
 *     (   ) = P (    )
 *     ( y )     ( g2 )                                                */
 
-void lpf_do_btran(LPF *lpf, double x[])
+void lpf_btran(LPF *lpf, double x[])
 {     int m0 = lpf->m0;
       int m = lpf->m;
       int n = lpf->n;
@@ -601,6 +606,8 @@ void lpf_do_btran(LPF *lpf, double x[])
 #if _GLPLPF_DEBUG
       double *b;
 #endif
+      if (!lpf->valid)
+         xfault("lpf_btran: the factorization is not valid\n");
       xassert(0 <= m && m <= m0 + n);
 #if _GLPLPF_DEBUG
       /* save the right-hand side vector */
@@ -661,28 +668,35 @@ static void enlarge_sva(LPF *lpf, int new_size)
 *  SYNOPSIS
 *
 *  #include "glplpf.h"
-*  int lpf_update_it(LPF *lpf, int j);
+*  int lpf_update_it(LPF *lpf, int j, int bh, int len, const int ind[],
+*     const double val[]);
 *
 *  DESCRIPTION
 *
-*  The routine lpf_update_it recomputes the factorization of the basis
+*  The routine lpf_update_it updates the factorization of the basis
 *  matrix B after replacing its j-th column by a new vector.
 *
-*  The new j-th column of B is passed implicitly. It is assumed that it
-*  was saved before by the routine lpf_do_ftran (see above).
+*  The parameter j specifies the number of column of B, which has been
+*  replaced, 1 <= j <= m, where m is the order of B.
+*
+*  The parameter bh specifies the basis header entry for the new column
+*  of B, which is the number of the new column in some original matrix.
+*  This parameter is optional and can be specified as 0.
+*
+*  Row indices and numerical values of non-zero elements of the new
+*  column of B should be placed in locations ind[1], ..., ind[len] and
+*  val[1], ..., val[len], resp., where len is the number of non-zeros
+*  in the column. Neither zero nor duplicate elements are allowed.
 *
 *  RETURNS
 *
 *  0  The factorization has been successfully updated.
 *
+*  LPF_ESING
+*     New basis B is singular within the working precision.
+*
 *  LPF_ELIMIT
 *     Maximal number of additional rows and columns has been reached.
-*     The factorization remains unchanged.
-*
-*  LPF_ESING
-*     The factorization has been successfully updated, however, new
-*     basis B is singular with a working precision. Note that the new
-*     factorization remains valid in this case.
 *
 *  BACKGROUND
 *
@@ -791,7 +805,8 @@ static void enlarge_sva(LPF *lpf, int new_size)
 *
 *  and to keep the main equality do the same for matrix Q. */
 
-int lpf_update_it(LPF *lpf, int j)
+int lpf_update_it(LPF *lpf, int j, int bh, int len, const int ind[],
+      const double val[])
 {     int m0 = lpf->m0;
       int m = lpf->m;
 #if _GLPLPF_DEBUG
@@ -809,29 +824,48 @@ int lpf_update_it(LPF *lpf, int j)
       int v_ptr = lpf->v_ptr;
       int *v_ind = lpf->v_ind;
       double *v_val = lpf->v_val;
-      double *newcol = lpf->newcol;
+      double *a = lpf->work2; /* new column */
       double *fg = lpf->work1, *f = fg, *g = fg + m0;
       double *vw = lpf->work2, *v = vw, *w = vw + m0;
       double *x = g, *y = w, z;
-      int i, ii, ret = 0;
-      if (!lpf->saved)
-         xfault("lpf_update_it: new column has not been prepared\n");
+      int i, ii, k, ret;
+      xassert(bh == bh);
+      if (!lpf->valid)
+         xfault("lpf_update_it: the factorization is not valid\n");
       if (!(1 <= j && j <= m))
          xfault("lpf_update_it: j = %d; column number out of range\n",
             j);
+      xassert(0 <= m && m <= m0 + n);
       /* check if the basis factorization can be expanded */
       if (n == lpf->n_max)
-      {  ret = LPF_ELIMIT;
+      {  lpf->valid = 0;
+         ret = LPF_ELIMIT;
          goto done;
       }
+      /* convert new j-th column of B to dense format */
+      for (i = 1; i <= m; i++)
+         a[i] = 0.0;
+      for (k = 1; k <= len; k++)
+      {  i = ind[k];
+         if (!(1 <= i && i <= m))
+            xfault("lpf_update_it: ind[%d] = %d; row number out of rang"
+               "e\n", k, i);
+         if (a[i] != 0.0)
+            xfault("lpf_update_it: ind[%d] = %d; duplicate row index no"
+               "t allowed\n", k, i);
+         if (val[k] == 0.0)
+            xfault("lpf_update_it: val[%d] = %g; zero element not allow"
+               "ed\n", k, val[k]);
+         a[i] = val[k];
+      }
 #if _GLPLPF_DEBUG
       /* change column in the basis matrix for debugging */
       for (i = 1; i <= m; i++)
-         B[(i - 1) * m + j] = newcol[i];
+         B[(i - 1) * m + j] = a[i];
 #endif
       /* (f g) := inv(P) * (a 0) */
       for (i = 1; i <= m0+n; i++)
-         fg[i] = ((ii = P_col[i]) <= m ? newcol[ii] : 0.0);
+         fg[i] = ((ii = P_col[i]) <= m ? a[ii] : 0.0);
       /* (v w) := Q * (ej 0) */
       for (i = 1; i <= m0+n; i++) vw[i] = 0.0;
       vw[Q_col[j]] = 1.0;
@@ -869,16 +903,16 @@ int lpf_update_it(LPF *lpf, int j)
       /* z := - v1 * f1 (new diagonal element of C) */
       z = 0.0;
       for (i = 1; i <= m0; i++) z -= v[i] * f[i];
-      /* update factorization of for new C */
+      /* update factorization of new matrix C */
       switch (scf_update_exp(lpf->scf, x, y, z))
       {  case 0:
             break;
+         case SCF_ESING:
+            lpf->valid = 0;
+            ret = LPF_ESING;
+            goto done;
          case SCF_ELIMIT:
             xassert(lpf != lpf);
-         case SCF_ESING:
-            /* C is singular, however, its factorization is valid */
-            ret = LPF_ESING;
-            break;
          default:
             xassert(lpf != lpf);
       }
@@ -893,9 +927,9 @@ int lpf_update_it(LPF *lpf, int j)
       /* increase the number of additional rows and columns */
       lpf->n++;
       xassert(lpf->n <= lpf->n_max);
-      /* reset the new column flag */
-      lpf->saved = 0;
-done: /* bring the return code to the calling program */
+      /* the factorization has been successfully updated */
+      ret = 0;
+done: /* return to the calling program */
       return ret;
 }
 
@@ -911,28 +945,28 @@ done: /* bring the return code to the calling program */
 *
 *  DESCRIPTION
 *
-*  The routine lpf_delete_it deletes the specified factorization and
-*  frees all the memory allocated to this object. */
+*  The routine lpf_delete_it deletes LP basis factorization specified
+*  by the parameter lpf and frees all memory allocated to this program
+*  object. */
 
 void lpf_delete_it(LPF *lpf)
-{     if (lpf->luf != NULL) luf_delete(lpf->luf);
+{     luf_delete_it(lpf->luf);
 #if _GLPLPF_DEBUG
       if (lpf->B != NULL) xfree(lpf->B);
 #else
       xassert(lpf->B == NULL);
 #endif
-      xfree(lpf->R_ptr);
-      xfree(lpf->R_len);
-      xfree(lpf->S_ptr);
-      xfree(lpf->S_len);
-      scf_delete_it(lpf->scf);
+      if (lpf->R_ptr != NULL) xfree(lpf->R_ptr);
+      if (lpf->R_len != NULL) xfree(lpf->R_len);
+      if (lpf->S_ptr != NULL) xfree(lpf->S_ptr);
+      if (lpf->S_len != NULL) xfree(lpf->S_len);
+      if (lpf->scf != NULL) scf_delete_it(lpf->scf);
       if (lpf->P_row != NULL) xfree(lpf->P_row);
       if (lpf->P_col != NULL) xfree(lpf->P_col);
       if (lpf->Q_row != NULL) xfree(lpf->Q_row);
       if (lpf->Q_col != NULL) xfree(lpf->Q_col);
-      xfree(lpf->v_ind);
-      xfree(lpf->v_val);
-      if (lpf->newcol != NULL) xfree(lpf->newcol);
+      if (lpf->v_ind != NULL) xfree(lpf->v_ind);
+      if (lpf->v_val != NULL) xfree(lpf->v_val);
       if (lpf->work1 != NULL) xfree(lpf->work1);
       if (lpf->work2 != NULL) xfree(lpf->work2);
       xfree(lpf);
