@@ -1,29 +1,26 @@
 /* glplpx03.c (control parameters and statistics routines) */
 
-/*----------------------------------------------------------------------
--- This code is part of GNU Linear Programming Kit (GLPK).
---
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
--- Department for Applied Informatics, Moscow Aviation Institute,
--- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
---
--- GLPK is free software; you can redistribute it and/or modify it
--- under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2, or (at your option)
--- any later version.
---
--- GLPK is distributed in the hope that it will be useful, but WITHOUT
--- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
--- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
--- License for more details.
---
--- You should have received a copy of the GNU General Public License
--- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
--- 02110-1301, USA.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  This code is part of GLPK (GNU Linear Programming Kit).
+*
+*  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
+*  Department for Applied Informatics, Moscow Aviation Institute,
+*  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
+*
+*  GLPK is free software: you can redistribute it and/or modify it
+*  under the terms of the GNU General Public License as published by
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
+*
+*  GLPK is distributed in the hope that it will be useful, but WITHOUT
+*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+*  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+*  License for more details.
+*
+*  You should have received a copy of the GNU General Public License
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
+***********************************************************************/
 
-#define _GLPAPI_PRIVATE
 #include "glpapi.h"
 #define fault xfault1
 
@@ -55,7 +52,7 @@ void lpx_reset_parms(LPX *lp)
       cps->obj_ll   = -DBL_MAX;
       cps->obj_ul   = +DBL_MAX;
       cps->it_lim   = -1;
-      cps->it_cnt   = 0;
+      lp->it_cnt   = 0;
       cps->tm_lim   = -1.0;
       cps->out_frq  = 200;
       cps->out_dly  = 0.0;
@@ -73,7 +70,6 @@ void lpx_reset_parms(LPX *lp)
       cps->presol = 0;
       cps->binarize = 0;
       cps->use_cuts = 0;
-      cps->bf_type = 1;
       return;
 }
 
@@ -128,7 +124,7 @@ void lpx_set_int_parm(LPX *lp, int parm, int val)
             cps->it_lim = val;
             break;
          case LPX_K_ITCNT:
-            cps->it_cnt = val;
+            lp->it_cnt = val;
             break;
          case LPX_K_OUTFRQ:
             if (!(val > 0))
@@ -209,10 +205,28 @@ void lpx_set_int_parm(LPX *lp, int parm, int val)
             cps->use_cuts = val;
             break;
          case LPX_K_BFTYPE:
+#if 0
             if (!(1 <= val && val <= 3))
                fault("lpx_set_int_parm: BFTYPE = %d; invalid value",
                   val);
             cps->bf_type = val;
+#else
+            {  glp_bfcp parm;
+               glp_get_bfcp(lp, &parm);
+               switch (val)
+               {  case 1:
+                     parm.type = GLP_BF_FT; break;
+                  case 2:
+                     parm.type = GLP_BF_BG; break;
+                  case 3:
+                     parm.type = GLP_BF_GR; break;
+                  default:
+                     fault("lpx_set_int_parm: BFTYPE = %d; invalid valu"
+                        "e", val);
+               }
+               glp_set_bfcp(lp, &parm);
+            }
+#endif
             break;
          default:
             fault("lpx_set_int_parm: parm = %d; invalid parameter",
@@ -251,7 +265,7 @@ int lpx_get_int_parm(LPX *lp, int parm)
          case LPX_K_ITLIM:
             val = cps->it_lim; break;
          case LPX_K_ITCNT:
-            val = cps->it_cnt; break;
+            val = lp->it_cnt; break;
          case LPX_K_OUTFRQ:
             val = cps->out_frq; break;
          case LPX_K_BRANCH:
@@ -279,7 +293,24 @@ int lpx_get_int_parm(LPX *lp, int parm)
          case LPX_K_USECUTS:
             val = cps->use_cuts; break;
          case LPX_K_BFTYPE:
+#if 0
             val = cps->bf_type; break;
+#else
+            {  glp_bfcp parm;
+               glp_get_bfcp(lp, &parm);
+               switch (parm.type)
+               {  case GLP_BF_FT:
+                     val = 1; break;
+                  case GLP_BF_BG:
+                     val = 2; break;
+                  case GLP_BF_GR:
+                     val = 3; break;
+                  default:
+                     xassert(lp != lp);
+               }
+            }
+            break;
+#endif
          default:
             fault("lpx_get_int_parm: parm = %d; invalid parameter",
                parm);
