@@ -1,32 +1,32 @@
 /* glplpx04.c (problem scaling routines) */
 
-/*----------------------------------------------------------------------
--- This code is part of GNU Linear Programming Kit (GLPK).
---
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
--- Department for Applied Informatics, Moscow Aviation Institute,
--- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
---
--- GLPK is free software; you can redistribute it and/or modify it
--- under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2, or (at your option)
--- any later version.
---
--- GLPK is distributed in the hope that it will be useful, but WITHOUT
--- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
--- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
--- License for more details.
---
--- You should have received a copy of the GNU General Public License
--- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
--- 02110-1301, USA.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  This code is part of GLPK (GNU Linear Programming Kit).
+*
+*  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
+*  Department for Applied Informatics, Moscow Aviation Institute,
+*  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
+*
+*  GLPK is free software: you can redistribute it and/or modify it
+*  under the terms of the GNU General Public License as published by
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
+*
+*  GLPK is distributed in the hope that it will be useful, but WITHOUT
+*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+*  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+*  License for more details.
+*
+*  You should have received a copy of the GNU General Public License
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
+***********************************************************************/
 
 #include "glpapi.h"
 #include "glplib.h"
 #define print xprint1
 #define fault xfault1
+#define lpx_set_rii glp_set_rii
+#define lpx_set_sjj glp_set_sjj
 
 /*----------------------------------------------------------------------
 -- eq_scal - implicit equilibration scaling.
@@ -400,29 +400,4 @@ skip: /* enter the scaling matrices R and S into the problem object and
       return;
 }
 
-/*----------------------------------------------------------------------
--- lpx_unscale_prob - unscale problem data.
---
--- *Synopsis*
---
--- #include "glplpx.h"
--- void lpx_unscale_prob(LPX *lp);
---
--- *Description*
---
--- The routine lpx_unscale_prob performs unscaling of problem data for
--- the specified problem object.
---
--- "Unscaling" means replacing the current scaling matrices R and S by
--- unity matrices that cancels the scaling effect. */
-
-void lpx_unscale_prob(LPX *lp)
-{     int m = lpx_get_num_rows(lp);
-      int n = lpx_get_num_cols(lp);
-      int i, j;
-      for (i = 1; i <= m; i++) lpx_set_rii(lp, i, 1.0);
-      for (j = 1; j <= n; j++) lpx_set_sjj(lp, j, 1.0);
-      return;
-}
-
 /* eof */
