@@ -1,32 +1,34 @@
 /* glplpx08.c (branch-and-bound solver routine) */
 
-/*----------------------------------------------------------------------
--- This code is part of GNU Linear Programming Kit (GLPK).
---
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
--- Department for Applied Informatics, Moscow Aviation Institute,
--- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
---
--- GLPK is free software; you can redistribute it and/or modify it
--- under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2, or (at your option)
--- any later version.
---
--- GLPK is distributed in the hope that it will be useful, but WITHOUT
--- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
--- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
--- License for more details.
---
--- You should have received a copy of the GNU General Public License
--- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
--- 02110-1301, USA.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  This code is part of GLPK (GNU Linear Programming Kit).
+*
+*  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
+*  Department for Applied Informatics, Moscow Aviation Institute,
+*  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
+*
+*  GLPK is free software: you can redistribute it and/or modify it
+*  under the terms of the GNU General Public License as published by
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
+*
+*  GLPK is distributed in the hope that it will be useful, but WITHOUT
+*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+*  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+*  License for more details.
+*
+*  You should have received a copy of the GNU General Public License
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
+***********************************************************************/
 
-#include "glpk.h"
+#include "glpapi.h"
 #include "glplib.h"
 #include "glpmip.h"
 #define print xprint1
+#define lpx_set_rii glp_set_rii
+#define lpx_set_sjj glp_set_sjj
+#define lpx_get_rii glp_get_rii
+#define lpx_get_sjj glp_get_sjj
 
 /*----------------------------------------------------------------------
 -- lpx_integer - easy-to-use driver to the branch-and-bound method.
