@@ -1,279 +1,34 @@
 /* glplpx11.c (LP basis and simplex table routines) */
 
-/*----------------------------------------------------------------------
--- This code is part of GNU Linear Programming Kit (GLPK).
---
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
--- Department for Applied Informatics, Moscow Aviation Institute,
--- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
---
--- GLPK is free software; you can redistribute it and/or modify it
--- under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2, or (at your option)
--- any later version.
---
--- GLPK is distributed in the hope that it will be useful, but WITHOUT
--- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
--- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
--- License for more details.
---
--- You should have received a copy of the GNU General Public License
--- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
--- 02110-1301, USA.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  This code is part of GLPK (GNU Linear Programming Kit).
+*
+*  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
+*  Department for Applied Informatics, Moscow Aviation Institute,
+*  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
+*
+*  GLPK is free software: you can redistribute it and/or modify it
+*  under the terms of the GNU General Public License as published by
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
+*
+*  GLPK is distributed in the hope that it will be useful, but WITHOUT
+*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+*  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+*  License for more details.
+*
+*  You should have received a copy of the GNU General Public License
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
+***********************************************************************/
 
 #include "glpapi.h"
 #include "glplib.h"
 #define fault xfault1
-
-/*----------------------------------------------------------------------
--- lpx_invert - compute factorization of basis matrix.
---
--- *Synopsis*
---
--- #include "glplpx.h"
--- int lpx_invert(LPX *lp);
---
--- *Description*
---
--- The routine lpx_invert computes factorization of the current basis
--- matrix for the specified problem object.
---
--- *Returns*
---
--- The routine lpx_invert returns one of the following error codes:
---
--- 0 - factorization has been successfully computed;
--- 1 - the basis matrix is singular;
--- 2 - the basis matrix is ill-conditioned;
--- 3 - either the problem object has no rows or the current basis is
---     invalid (the number of basic variables is not the same as the
---     number of rows). */
-
-struct invert_info
-{     /* transitional info passed to the routine basic_column */
-      LPX *lp;
-      /* pointer to the problem object */
-      int *basis; /* int basis[1+m]; */
-      /* list of basic variables (basis header) */
-};
-
-static int basic_column(void *_info, int j, int rn[], double bj[])
-{     /* this routine returns row indices and numeric values of
-         non-zero elements in j-th column of the basis matrix to be
-         factorized */
-      struct invert_info *info = _info;
-      int k, m, t, len;
-      double rii, sjj;
-      m = lpx_get_num_rows(info->lp);
-      /* determine the ordinal number of basic auxiliary or structural
-         variable, which corresponds to j-th basic variable xB[j] */
-      xassert(1 <= j && j <= m);
-      k = info->basis[j];
-      /* construct j-th column of the basis matrix */
-      if (k <= m)
-      {  /* x[k] is auxiliary variable */
-         len = 1;
-         rn[1] = k;
-         bj[1] = 1.0;
-      }
-      else
-      {  /* x[k] is structural variable */
-         len = lpx_get_mat_col(info->lp, k-m, rn, bj);
-         /* scale the column and change its sign */
-         sjj = lpx_get_sjj(info->lp, k-m);
-         for (t = 1; t <= len; t++)
-         {  rii = lpx_get_rii(info->lp, rn[t]);
-            bj[t] *= - rii * sjj;
-         }
-      }
-      return len;
-}
-
-int lpx_invert(LPX *lp)
-{     /* compute factorization of basis matrix */
-      struct invert_info info;
-      BFI *b_inv = lpx_access_inv(lp);
-      int i, k, m, n, ret, stat, *basis;
-      m = lpx_get_num_rows(lp);
-      n = lpx_get_num_cols(lp);
-      /* build the list of basic variables (basis header) */
-      basis = xcalloc(1+m, sizeof(int));
-      i = 0;
-      for (k = 1; k <= m+n; k++)
-      {  if (k <= m)
-            stat = lpx_get_row_stat(lp, k);
-         else
-            stat = lpx_get_col_stat(lp, k-m);
-         if (stat == LPX_BS)
-         {  i++;
-            if (i > m)
-            {  /* too many basic variables */
-               ret = 3;
-               goto fini;
-            }
-            basis[i] = k;
-         }
-      }
-      if (i < m)
-      {  /* too few basic variables */
-         ret = 3;
-         goto fini;
-      }
-#if 0
-      /* access factorization data structure */
-      b_inv = lpx_access_inv(lp);
-#endif
-      /* try to factorize the basis matrix */
-      if (m == 0)
-      {  /* the problem object has no rows */
-         ret = 3;
-         goto fini;
-      }
-      info.lp = lp;
-      info.basis = basis;
-      ret = bfi_factorize(b_inv, m, basic_column, &info);
-      xassert(ret == 0 || ret == 1 || ret == 2);
-fini: /* put the basis back to the problem object */
-      lpx_put_lp_basis(lp, (ret == 0 ? LPX_B_VALID : LPX_B_UNDEF),
-         basis, b_inv);
-      xfree(basis);
-      return ret;
-}
-
-/*----------------------------------------------------------------------
--- lpx_ftran - forward transformation (solve system B*x = b).
---
--- *Synopsis*
---
--- #include "glplpx.h"
--- void lpx_ftran(LPX *lp, double x[]);
---
--- *Description*
---
--- The routine lpx_ftran performs forward transformation, i.e. solves
--- the system B*x = b, where B is the basis matrix corresponding to the
--- current basis for the specified problem object, x is the vector of
--- unknowns to be computed, b is the vector of right-hand sides.
---
--- On entry elements of the vector b should be stored in dense format
--- in locations x[1], ..., x[m], where m is the number of rows. On exit
--- the routine stores elements of the vector x in the same locations.
---
--- *Scaling/Unscaling*
---
--- Let A~ = (I | -A) is the augmented constraint matrix of the original
--- (unscaled) problem. In the scaled LP problem instead the matrix A the
--- scaled matrix A" = R*A*S is actually used, so
---
---    A~" = (I | A") = (I | R*A*S) = (R*I*inv(R) | R*A*S) =
---                                                                   (1)
---        = R*(I | A)*S~ = R*A~*S~,
---
--- is the scaled augmented constraint matrix, where R and S are diagonal
--- scaling matrices used to scale rows and columns of the matrix A, and
---
---    S~ = diag(inv(R) | S)                                          (2)
---
--- is an augmented diagonal scaling matrix.
---
--- By definition:
---
---    A~ = (B | N),                                                  (3)
---
--- where B is the basic matrix, which consists of basic columns of the
--- augmented constraint matrix A~, and N is a matrix, which consists of
--- non-basic columns of A~. From (1) it follows that:
---
---    A~" = (B" | N") = (R*B*SB | R*N*SN),                           (4)
---
--- where SB and SN are parts of the augmented scaling matrix S~, which
--- correspond to basic and non-basic variables, respectively. Therefore
---
---    B" = R*B*SB,                                                   (5)
---
--- which is the scaled basis matrix. */
-
-void lpx_ftran(LPX *lp, double x[])
-{     /* B*x = b ===> (R*B*SB)*(inv(SB)*x) = R*b ===> B"*x" = b",
-         where b" = R*b, x = SB*x" */
-      BFI *b_inv;
-      int i, k, m;
-      if (!lpx_is_b_avail(lp))
-         fault("lpx_ftran: LP basis is not available");
-      m = lpx_get_num_rows(lp);
-      /* compute b" = R*b */
-      for (i = 1; i <= m; i++)
-      {  if (x[i] == 0.0) continue;
-         x[i] *= lpx_get_rii(lp, i);
-      }
-      /* solve the system B"*x" = b" */
-      b_inv = lpx_access_inv(lp);
-      bfi_ftran(b_inv, x, 0);
-      /* compute x = SB*x" */
-      for (i = 1; i <= m; i++)
-      {  if (x[i] == 0.0) continue;
-         k = lpx_get_b_info(lp, i); /* x[k] = xB[i] */
-         if (k <= m)
-            x[i] /= lpx_get_rii(lp, k);
-         else
-            x[i] *= lpx_get_sjj(lp, k-m);
-      }
-      return;
-}
-
-/*----------------------------------------------------------------------
--- lpx_btran - backward transformation (solve system B'*x = b).
---
--- *Synopsis*
---
--- #include "glplpx.h"
--- void lpx_btran(LPX *lp, double x[]);
---
--- *Description*
---
--- The routine lpx_btran performs backward transformation, i.e. solves
--- the system B'*x = b, where B' is a matrix transposed to the basis
--- matrix corresponding to the current basis for the specified problem
--- problem object, x is the vector of unknowns to be computed, b is the
--- vector of right-hand sides.
---
--- On entry elements of the vector b should be stored in dense format
--- in locations x[1], ..., x[m], where m is the number of rows. On exit
--- the routine stores elements of the vector x in the same locations.
---
--- *Scaling/Unscaling*
---
--- See comments to the routine lpx_ftran. */
-
-void lpx_btran(LPX *lp, double x[])
-{     /* B'*x = b ===> (SB*B'*R)*(inv(R)*x) = SB*b ===> (B")'*x" = b",
-         where b" = SB*b, x = R*x" */
-      BFI *b_inv;
-      int i, k, m;
-      if (!lpx_is_b_avail(lp))
-         fault("lpx_btran: LP basis is not available");
-      m = lpx_get_num_rows(lp);
-      /* compute b" = SB*b */
-      for (i = 1; i <= m; i++)
-      {  if (x[i] == 0.0) continue;
-         k = lpx_get_b_info(lp, i); /* x[k] = xB[i] */
-         if (k <= m)
-            x[i] /= lpx_get_rii(lp, k);
-         else
-            x[i] *= lpx_get_sjj(lp, k-m);
-      }
-      /* solve the system (B")'*x" = b" */
-      b_inv = lpx_access_inv(lp);
-      bfi_btran(b_inv, x);
-      /* compute x = R*x" */
-      for (i = 1; i <= m; i++)
-      {  if (x[i] == 0.0) continue;
-         x[i] *= lpx_get_rii(lp, i);
-      }
-      return;
-}
+#define lpx_get_b_info glp_get_bhead
+#define lpx_get_row_b_ind glp_get_row_bind
+#define lpx_get_col_b_ind glp_get_col_bind
+#define lpx_ftran glp_ftran
+#define lpx_btran glp_btran
 
 /*----------------------------------------------------------------------
 -- lpx_eval_b_prim - compute primal basic solution components.
@@ -533,6 +288,7 @@ int lpx_warm_up(LPX *lp)
          {  ret = LPX_E_EMPTY;
             goto done;
          }
+#if 0
          ret = lpx_invert(lp);
          switch (ret)
          {  case 0:
@@ -548,6 +304,22 @@ int lpx_warm_up(LPX *lp)
             default:
                xassert(ret != ret);
          }
+#else
+         switch (glp_factorize(lp))
+         {  case 0:
+               ret = LPX_E_OK;
+               break;
+            case GLP_EBADB:
+               ret = LPX_E_BADB;
+               goto done;
+            case GLP_ESING:
+            case GLP_ECOND:
+               ret = LPX_E_SING;
+               goto done;
+            default:
+               xassert(lp != lp);
+         }
+#endif
       }
       /* allocate working arrays */
       row_prim = xcalloc(1+m, sizeof(double));
