@@ -1,28 +1,27 @@
 /* glpspx01.c (simplex method generic routines) */
 
-/*----------------------------------------------------------------------
--- This code is part of GNU Linear Programming Kit (GLPK).
---
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
--- Department for Applied Informatics, Moscow Aviation Institute,
--- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
---
--- GLPK is free software; you can redistribute it and/or modify it
--- under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2, or (at your option)
--- any later version.
---
--- GLPK is distributed in the hope that it will be useful, but WITHOUT
--- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
--- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
--- License for more details.
---
--- You should have received a copy of the GNU General Public License
--- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
--- 02110-1301, USA.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  This code is part of GLPK (GNU Linear Programming Kit).
+*
+*  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
+*  Department for Applied Informatics, Moscow Aviation Institute,
+*  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
+*
+*  GLPK is free software: you can redistribute it and/or modify it
+*  under the terms of the GNU General Public License as published by
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
+*
+*  GLPK is distributed in the hope that it will be useful, but WITHOUT
+*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+*  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+*  License for more details.
+*
+*  You should have received a copy of the GNU General Public License
+*  along with this program. If not, see <http://www.gnu.org/licenses/>.
+***********************************************************************/
 
+#include "glpapi.h"
 #include "glplib.h"
 #include "glpspx.h"
 #define print xprint1
@@ -89,22 +88,22 @@ static int inv_col(void *info, int j, int rn[], double bj[])
 int spx_invert(SPX *spx)
 {     int ret;
       /* try to factorize the basis matrix */
-      ret = bfi_factorize(spx->inv, spx->m, inv_col, spx);
+      ret = bfd_factorize(spx->bfd, spx->m, spx->indx, inv_col, spx);
       /* analyze the return code */
       switch (ret)
       {  case 0:
             /* success */
-            spx->b_stat = LPX_B_VALID;
+            spx->valid = 1;
             break;
          case 1:
             if (spx->msg_lev >= 1)
                print("spx_invert: the basis matrix is singular");
-            spx->b_stat = LPX_B_UNDEF;
+            spx->valid = 0;
             break;
          case 2:
             if (spx->msg_lev >= 1)
                print("spx_invert: the basis matrix is ill-conditioned");
-            spx->b_stat = LPX_B_UNDEF;
+            spx->valid = 0;
             break;
          default:
             xassert(ret != ret);
@@ -119,7 +118,7 @@ int spx_invert(SPX *spx)
 -- *Synopsis*
 --
 -- #include "glpspx.h"
--- void spx_ftran(SPX *spx, double x[], int save);
+-- void spx_ftran(SPX *spx, double x[]);
 --
 -- *Description*
 --
@@ -134,20 +133,11 @@ int spx_invert(SPX *spx)
 -- On entry the array x should contain components of the vector x in
 -- locations x[1], x[2], ..., x[m], where m is the order of the basis
 -- matrix. On exit this array will contain components of the vector x'
--- in the same locations.
---
--- The parameter save is a flag. If this flag is set, it means that the
--- input vector x is a column of the non-basic variable, which has been
--- chosen to enter the basis. In this case the routine spx_ftran saves
--- this column (after partial transformation) in order that the routine
--- spx_update could update (recompute) the factorization for an adjacent
--- basis using this partially transformed column. The simplex method
--- routine should call the routine spx_ftran with the save flag set at
--- least once before a subsequent call to the routine spx_update. */
+-- in the same locations. */
 
-void spx_ftran(SPX *spx, double x[], int save)
-{     xassert(spx->b_stat == LPX_B_VALID);
-      bfi_ftran(spx->inv, x, save);
+void spx_ftran(SPX *spx, double x[])
+{     xassert(spx->valid);
+      bfd_ftran(spx->bfd, x);
       return;
 }
 
@@ -175,11 +165,12 @@ void spx_ftran(SPX *spx, double x[], int save)
 -- in the same locations. */
 
 void spx_btran(SPX *spx, double x[])
-{     xassert(spx->b_stat == LPX_B_VALID);
-      bfi_btran(spx->inv, x);
+{     xassert(spx->valid);
+      bfd_btran(spx->bfd, x);
       return;
 }
 
+#if 0 /* 02/VI-2007 */
 /*----------------------------------------------------------------------
 -- spx_update - update factorization for adjacent basis matrix.
 --
@@ -211,6 +202,7 @@ int spx_update(SPX *spx, int j)
       ret = bfi_update_binv(spx->inv, j);
       return ret;
 }
+#endif
 
 /*----------------------------------------------------------------------
 -- spx_eval_xn_j - determine value of non-basic variable.
@@ -230,27 +222,27 @@ double spx_eval_xn_j(SPX *spx, int j)
       int n = spx->n;
       double *lb = spx->lb;
       double *ub = spx->ub;
-      int *tagx = spx->tagx;
+      int *stat = spx->stat;
       int *indx = spx->indx;
       int k;
       double xn_j;
       xassert(1 <= j && j <= n);
       k = indx[m+j]; /* x[k] = xN[j] */
-      switch (tagx[k])
-      {  case LPX_NL:
+      switch (stat[k])
+      {  case GLP_NL:
             /* xN[j] is on its lower bound */
             xn_j = lb[k]; break;
-         case LPX_NU:
+         case GLP_NU:
             /* xN[j] is on its upper bound */
             xn_j = ub[k]; break;
-         case LPX_NF:
+         case GLP_NF:
             /* xN[j] is free variable */
             xn_j = 0.0; break;
-         case LPX_NS:
+         case GLP_NS:
             /* xN[j] is fixed variable */
             xn_j = lb[k]; break;
          default:
-            xassert(tagx != tagx);
+            xassert(stat != stat);
       }
       return xn_j;
 }
@@ -309,7 +301,7 @@ void spx_eval_bbar(SPX *spx)
          }
       }
       /* bbar := inv(B) * rhs */
-      spx_ftran(spx, rhs, 0);
+      spx_ftran(spx, rhs);
       return;
 }
 
@@ -424,14 +416,14 @@ void spx_eval_cbar(SPX *spx)
 double spx_eval_obj(SPX *spx)
 {     int m = spx->m;
       int n = spx->n;
-      int *tagx = spx->tagx;
+      int *stat = spx->stat;
       int *posx = spx->posx;
       double *coef = spx->coef;
       double *bbar = spx->bbar;
       int i, j, k;
       double obj = coef[0];
       for (k = 1; k <= m+n; k++)
-      {  if (tagx[k] == LPX_BS)
+      {  if (stat[k] == GLP_BS)
          {  /* x[k] = xB[i] */
             i = posx[k];
             xassert(1 <= i && i <= m);
@@ -497,7 +489,12 @@ void spx_eval_col(SPX *spx, int j, double col[], int save)
             rhs[AT_ind[j_ptr]] = - AT_val[j_ptr];
       }
       /* A^[j] := - inv(B) * N[j] */
+#if 0 /* 02/VI-2007 */
       spx_ftran(spx, rhs, save);
+#else
+      xassert(save == save);
+      spx_ftran(spx, rhs);
+#endif
       for (i = 1; i <= m; i++) col[i] = - col[i];
       return;
 }
@@ -620,25 +617,25 @@ void spx_eval_row(SPX *spx, double rho[], double row[])
 
 double spx_check_bbar(SPX *spx, double tol)
 {     int m = spx->m;
-      int *typx = spx->typx;
+      int *type = spx->type;
       double *lb = spx->lb;
       double *ub = spx->ub;
       int *indx = spx->indx;
       double *bbar = spx->bbar;
-      int i, k, typx_k;
+      int i, k, type_k;
       double lb_k, ub_k, bbar_i;
       double sum = 0.0;
       for (i = 1; i <= m; i++)
       {  k = indx[i]; /* x[k] = xB[i] */
-         typx_k = typx[k];
+         type_k = type[k];
          bbar_i = bbar[i];
-         if (typx_k == LPX_LO || typx_k == LPX_DB || typx_k == LPX_FX)
+         if (type_k == GLP_LO || type_k == GLP_DB || type_k == GLP_FX)
          {  /* xB[i] has lower bound */
             lb_k = lb[k];
             if ((lb_k - bbar_i) / (1.0 + fabs(lb_k)) > tol)
                sum += (lb_k - bbar_i);
          }
-         if (typx_k == LPX_UP || typx_k == LPX_DB || typx_k == LPX_FX)
+         if (type_k == GLP_UP || type_k == GLP_DB || type_k == GLP_FX)
          {  /* xB[i] has upper bound */
             ub_k = ub[k];
             if ((bbar_i - ub_k) / (1.0 + fabs(ub_k)) > tol)
@@ -670,22 +667,22 @@ double spx_check_bbar(SPX *spx, double tol)
 double spx_check_cbar(SPX *spx, double tol)
 {     int m = spx->m;
       int n = spx->n;
-      double dir = (spx->dir == LPX_MIN ? +1.0 : -1.0);
-      int *tagx = spx->tagx;
+      double dir = (spx->dir == GLP_MIN ? +1.0 : -1.0);
+      int *stat = spx->stat;
       int *indx = spx->indx;
       double *cbar = spx->cbar;
-      int j, k, tagx_k;
+      int j, k, stat_k;
       double cbar_j;
       double sum = 0.0;
       for (j = 1; j <= n; j++)
       {  k = indx[m+j]; /* x[k] = xN[j] */
-         tagx_k = tagx[k];
+         stat_k = stat[k];
          cbar_j = dir * cbar[j];
-         if (tagx_k == LPX_NF || tagx_k == LPX_NL)
+         if (stat_k == GLP_NF || stat_k == GLP_NL)
          {  /* xN[j] can increase */
             if (cbar_j < - tol) sum -= cbar_j;
          }
-         if (tagx_k == LPX_NF || tagx_k == LPX_NU)
+         if (stat_k == GLP_NF || stat_k == GLP_NU)
          {  /* xN[j] can decrease */
             if (cbar_j > + tol) sum += cbar_j;
          }
@@ -732,12 +729,12 @@ double spx_check_cbar(SPX *spx, double tol)
 int spx_prim_chuzc(SPX *spx, double tol)
 {     int m = spx->m;
       int n = spx->n;
-      double dir = (spx->dir == LPX_MIN ? +1.0 : -1.0);
+      double dir = (spx->dir == GLP_MIN ? +1.0 : -1.0);
       double *coef = spx->coef;
       int *AT_ptr = spx->AT_ptr;
       int *AT_ind = spx->AT_ind;
       double *AT_val = spx->AT_val;
-      int *tagx = spx->tagx;
+      int *stat = spx->stat;
       int *indx = spx->indx;
       double *pi = spx->pi;
       double *cbar = spx->cbar;
@@ -759,24 +756,24 @@ loop: /* recompute basic solution components (if required) */
          if (cbar_j == 0.0) continue;
          /* analyze main cases */
          k = indx[m+j]; /* x[k] = xN[j] */
-         switch (tagx[k])
-         {  case LPX_NL:
+         switch (stat[k])
+         {  case GLP_NL:
                /* xN[j] can increase */
                if (cbar_j > -tol) continue;
                break;
-            case LPX_NU:
+            case GLP_NU:
                /* xN[j] can decrease */
                if (cbar_j < +tol) continue;
                break;
-            case LPX_NF:
+            case GLP_NF:
                /* xN[j] can change in any direction */
                if (-tol < cbar_j && cbar_j < +tol) continue;
                break;
-            case LPX_NS:
+            case GLP_NS:
                /* xN[j] can't change */
                continue;
             default:
-               xassert(tagx != tagx);
+               xassert(stat != stat);
          }
          /* xN[j] can improve the objective function */
          temp = (cbar_j * cbar_j) / gvec[j];
@@ -875,10 +872,10 @@ loop: /* recompute basic solution components (if required) */
 int spx_prim_chuzr(SPX *spx, double relax)
 {     int m = spx->m;
       int n = spx->n;
-      int *typx = spx->typx;
+      int *type = spx->type;
       double *lb = spx->lb;
       double *ub = spx->ub;
-      double dir = (spx->dir == LPX_MIN ? +1.0 : -1.0);
+      double dir = (spx->dir == GLP_MIN ? +1.0 : -1.0);
       double *bbar = spx->bbar;
       double *cbar = spx->cbar;
       int *indx = spx->indx;
@@ -910,7 +907,7 @@ int spx_prim_chuzr(SPX *spx, double relax)
       eps = spx->tol_piv * (1.0 + big);
       /* initial settings for the first pass */
       k = indx[m+q]; /* x[k] = xN[q] */
-      if (typx[k] == LPX_DB)
+      if (type[k] == GLP_DB)
       {  /* xN[q] has both lower and upper bounds */
          p = -1, p_tag = 0, teta = (ub[k] - lb[k]) + relax, big = 1.0;
       }
@@ -926,33 +923,33 @@ int spx_prim_chuzr(SPX *spx, double relax)
          abs_aq_i = (aq_i > 0.0 ? +aq_i : -aq_i);
          /* analyze main cases */
          k = indx[i]; /* x[k] = xB[i] */
-         switch (typx[k])
-         {  case LPX_FR:
+         switch (type[k])
+         {  case GLP_FR:
                /* xB[i] is free variable */
                continue;
-            case LPX_LO:
+            case GLP_LO:
 lo_1:          /* xB[i] has lower bound */
                if (aq_i > -eps) continue;
-               i_tag = LPX_NL;
+               i_tag = GLP_NL;
                temp = ((lb[k] - relax) - bbar[i]) / aq_i;
                break;
-            case LPX_UP:
+            case GLP_UP:
                /* xB[i] has upper bound */
 up_1:          if (aq_i < +eps) continue;
-               i_tag = LPX_NU;
+               i_tag = GLP_NU;
                temp = ((ub[k] + relax) - bbar[i]) / aq_i;
                break;
-            case LPX_DB:
+            case GLP_DB:
                /* xB[i] has both lower and upper bounds */
                if (aq_i < 0.0) goto lo_1; else goto up_1;
-            case LPX_FX:
+            case GLP_FX:
                /* xB[i] is fixed variable */
                if (abs_aq_i < eps) continue;
-               i_tag = LPX_NS;
+               i_tag = GLP_NS;
                temp = relax / abs_aq_i;
                break;
             default:
-               xassert(typx != typx);
+               xassert(type != type);
          }
          /* if xB[i] violates its bound (slightly, because the current
             basis is assumed to be primal feasible), temp is negative;
@@ -980,7 +977,7 @@ up_1:          if (aq_i < +eps) continue;
       /* if xN[q] is double-bounded variable and can go to the opposite
          bound, it is reasonable to choose it */
       k = indx[m+q]; /* x[k] = xN[q] */
-      if (typx[k] == LPX_DB && ub[k] - lb[k] <= teta)
+      if (type[k] == GLP_DB && ub[k] - lb[k] <= teta)
       {  p = -1, p_tag = 0;
          goto done;
       }
@@ -994,33 +991,33 @@ up_1:          if (aq_i < +eps) continue;
          abs_aq_i = (aq_i > 0.0 ? +aq_i : -aq_i);
          /* analyze main cases */
          k = indx[i]; /* x[k] = xB[i] */
-         switch (typx[k])
-         {  case LPX_FR:
+         switch (type[k])
+         {  case GLP_FR:
                /* xB[i] is free variable */
                continue;
-            case LPX_LO:
+            case GLP_LO:
 lo_2:          /* xB[i] has lower bound */
                if (aq_i > -eps) continue;
-               i_tag = LPX_NL;
+               i_tag = GLP_NL;
                temp = (lb[k] - bbar[i]) / aq_i;
                break;
-            case LPX_UP:
+            case GLP_UP:
 up_2:          /* xB[i] has upper bound */
                if (aq_i < +eps) continue;
-               i_tag = LPX_NU;
+               i_tag = GLP_NU;
                temp = (ub[k] - bbar[i]) / aq_i;
                break;
-            case LPX_DB:
+            case GLP_DB:
                /* xB[i] has both lower and upper bounds */
                if (aq_i < 0.0) goto lo_2; else goto up_2;
-            case LPX_FX:
+            case GLP_FX:
                /* xB[i] is fixed variable */
                if (abs_aq_i < eps) continue;
-               i_tag = LPX_NS;
+               i_tag = GLP_NS;
                temp = 0.0;
                break;
             default:
-               xassert(typx != typx);
+               xassert(type != type);
          }
          /* see comments about this trick in the first pass loop */
          if (temp < 0.0) temp = 0.0;
@@ -1080,22 +1077,22 @@ done: /* restore original signs of the coefficients aq[i] */
 
 void spx_dual_chuzr(SPX *spx, double tol)
 {     int m = spx->m;
-      int *typx = spx->typx;
+      int *type = spx->type;
       double *lb = spx->lb;
       double *ub = spx->ub;
       int *indx = spx->indx;
       double *bbar = spx->bbar;
       double *dvec = spx->dvec;
-      int i, k, p, p_tag, typx_k;
+      int i, k, p, p_tag, type_k;
       double best, lb_k, ub_k, bbar_i, temp;
       /* nothing chosen so far */
       p = 0, p_tag = 0, best = 0.0;
       /* look through the list of basic variables */
       for (i = 1; i <= m; i++)
       {  k = indx[i]; /* x[k] = xB[i] */
-         typx_k = typx[k];
+         type_k = type[k];
          bbar_i = bbar[i];
-         if (typx_k == LPX_LO || typx_k == LPX_DB || typx_k == LPX_FX)
+         if (type_k == GLP_LO || type_k == GLP_DB || type_k == GLP_FX)
          {  /* xB[i] has lower bound */
             lb_k = lb[k];
             temp = bbar_i - lb_k;
@@ -1103,10 +1100,10 @@ void spx_dual_chuzr(SPX *spx, double tol)
             if (temp / (1.0 + lb_k) < - tol)
             {  /* xB[i] violates its lower bound */
                temp = (temp * temp) / dvec[i];
-               if (best < temp) p = i, p_tag = LPX_NL, best = temp;
+               if (best < temp) p = i, p_tag = GLP_NL, best = temp;
             }
          }
-         if (typx_k == LPX_UP || typx_k == LPX_DB || typx_k == LPX_FX)
+         if (type_k == GLP_UP || type_k == GLP_DB || type_k == GLP_FX)
          {  /* xB[i] has upper bound */
             ub_k = ub[k];
             temp = bbar_i - ub_k;
@@ -1114,7 +1111,7 @@ void spx_dual_chuzr(SPX *spx, double tol)
             if (temp / (1.0 + ub_k) > + tol)
             {  /* xB[i] violates its upper bound */
                temp = (temp * temp) / dvec[i];
-               if (best < temp) p = i, p_tag = LPX_NU, best = temp;
+               if (best < temp) p = i, p_tag = GLP_NU, best = temp;
             }
          }
       }
@@ -1154,9 +1151,9 @@ void spx_dual_chuzr(SPX *spx, double tol)
 int spx_dual_chuzc(SPX *spx, double relax)
 {     int m = spx->m;
       int n = spx->n;
-      double dir = (spx->dir == LPX_MIN ? +1.0 : -1.0);
+      double dir = (spx->dir == GLP_MIN ? +1.0 : -1.0);
       int *indx = spx->indx;
-      int *tagx = spx->tagx;
+      int *stat = spx->stat;
       double *cbar = spx->cbar;
       int p = spx->p;
       int p_tag = spx->p_tag;
@@ -1164,10 +1161,10 @@ int spx_dual_chuzc(SPX *spx, double relax)
       int j, k, q, ret = 0;
       double big, eps, teta, ap_j, abs_ap_j, temp;
       xassert(1 <= p && p <= m);
-      xassert(p_tag == LPX_NL || p_tag == LPX_NU);
+      xassert(p_tag == GLP_NL || p_tag == GLP_NU);
       /* turn to the case of increasing xB[p] in order to simplify the
          program logic */
-      if (p_tag == LPX_NU)
+      if (p_tag == GLP_NU)
          for (j = 1; j <= n; j++) ap[j] = - ap[j];
       /* compute the largest absolute value of elements of the p-th row
          of the simplex table */
@@ -1196,27 +1193,27 @@ int spx_dual_chuzc(SPX *spx, double relax)
          abs_ap_j = (ap_j > 0.0 ? +ap_j : -ap_j);
          /* analyze main cases */
          k = indx[m+j]; /* x[k] = xN[j] */
-         switch (tagx[k])
-         {  case LPX_NF:
+         switch (stat[k])
+         {  case GLP_NF:
                /* xN[j] is free variable */
                if (abs_ap_j < eps) continue;
                temp = relax / abs_ap_j;
                break;
-            case LPX_NL:
+            case GLP_NL:
                /* xN[j] is on its lower bound */
                if (ap_j < +eps) continue;
                temp = (dir * cbar[j] + relax) / ap_j;
                break;
-            case LPX_NU:
+            case GLP_NU:
                /* xN[j] is on its upper bound */
                if (ap_j > -eps) continue;
                temp = (dir * cbar[j] - relax) / ap_j;
                break;
-            case LPX_NS:
+            case GLP_NS:
                /* xN[j] is fixed variable */
                continue;
             default:
-               xassert(tagx != tagx);
+               xassert(stat != stat);
          }
          /* if reduced cost of xN[j] violates its zero bound (slightly,
             because the current basis is assumed to be dual feasible),
@@ -1252,27 +1249,27 @@ int spx_dual_chuzc(SPX *spx, double relax)
          abs_ap_j = (ap_j > 0.0 ? +ap_j : -ap_j);
          /* analyze main cases */
          k = indx[m+j]; /* x[k] = xN[j] */
-         switch (tagx[k])
-         {  case LPX_NF:
+         switch (stat[k])
+         {  case GLP_NF:
                /* xN[j] is free variable */
                if (abs_ap_j < eps) continue;
                temp = 0.0;
                break;
-            case LPX_NL:
+            case GLP_NL:
                /* xN[j] is on its lower bound */
                if (ap_j < +eps) continue;
                temp = (dir * cbar[j]) / ap_j;
                break;
-            case LPX_NU:
+            case GLP_NU:
                /* xN[j] is on its upper bound */
                if (ap_j > -eps) continue;
                temp = (dir * cbar[j]) / ap_j;
                break;
-            case LPX_NS:
+            case GLP_NS:
                /* xN[j] is fixed variable */
                continue;
             default:
-               xassert(tagx != tagx);
+               xassert(stat != stat);
          }
          /* see comments about this trick in the first pass loop */
          if (temp < 0.0) temp = 0.0;
@@ -1283,7 +1280,7 @@ int spx_dual_chuzc(SPX *spx, double relax)
       /* the second pass should always choose some xN[q] */
       xassert(1 <= q && q <= n);
 done: /* restore original signs of the coefficients ap[j] */
-      if (p_tag == LPX_NU)
+      if (p_tag == GLP_NU)
          for (j = 1; j <= n; j++) ap[j] = - ap[j];
       /* store the number q */
       spx->q = q;
@@ -1315,10 +1312,10 @@ done: /* restore original signs of the coefficients ap[j] */
 void spx_update_bbar(SPX *spx, double *obj)
 {     int m = spx->m;
       int n = spx->n;
-      int *typx = spx->typx;
+      int *type = spx->type;
       double *lb = spx->lb;
       double *ub = spx->ub;
-      int *tagx = spx->tagx;
+      int *stat = spx->stat;
       int *indx = spx->indx;
       double *bbar = spx->bbar;
       int p = spx->p;
@@ -1331,18 +1328,18 @@ void spx_update_bbar(SPX *spx, double *obj)
       {  /* the special case: xN[q] goes to its opposite bound */
          xassert(1 <= q && q <= n);
          k = indx[m+q]; /* x[k] = xN[q] */
-         xassert(typx[k] == LPX_DB);
-         switch (tagx[k])
-         {  case LPX_NL:
+         xassert(type[k] == GLP_DB);
+         switch (stat[k])
+         {  case GLP_NL:
                /* xN[q] goes from its lower bound to its upper one */
                dxn_q = ub[k] - lb[k];
                break;
-            case LPX_NU:
+            case GLP_NU:
                /* xN[q] goes from its upper bound to its lower one */
                dxn_q = lb[k] - ub[k];
                break;
             default:
-               xassert(tagx != tagx);
+               xassert(stat != stat);
          }
          /* recompute values of the basic variables */
          for (i = 1; i <= m; i++)
@@ -1357,13 +1354,13 @@ void spx_update_bbar(SPX *spx, double *obj)
          /* determine value of xB[p] in the adjacent basis */
          k = indx[p];
          switch (p_tag)
-         {  case LPX_NL:
+         {  case GLP_NL:
                new_xb_p = lb[k]; break;
-            case LPX_NU:
+            case GLP_NU:
                new_xb_p = ub[k]; break;
-            case LPX_NF:
+            case GLP_NF:
                new_xb_p = 0.0; break;
-            case LPX_NS:
+            case GLP_NS:
                new_xb_p = lb[k]; break;
             default:
                xassert(p_tag != p_tag);
@@ -1450,7 +1447,7 @@ void spx_update_pi(SPX *spx)
 void spx_update_cbar(SPX *spx, int all)
 {     int m = spx->m;
       int n = spx->n;
-      int *tagx = spx->tagx;
+      int *stat = spx->stat;
       int *indx = spx->indx;
       double *cbar = spx->cbar;
       int p = spx->p;
@@ -1469,7 +1466,7 @@ void spx_update_cbar(SPX *spx, int all)
       {  if (j == q) continue;
          if (!all)
          {  k = indx[m+j]; /* x[k] = xN[j] */
-            if (tagx[k] == LPX_NS)
+            if (stat[k] == GLP_NS)
             {  cbar[j] = 0.0;
                continue;
             }
@@ -1508,8 +1505,8 @@ void spx_update_cbar(SPX *spx, int all)
 int spx_change_basis(SPX *spx)
 {     int m = spx->m;
       int n = spx->n;
-      int *typx = spx->typx;
-      int *tagx = spx->tagx;
+      int *type = spx->type;
+      int *stat = spx->stat;
       int *posx = spx->posx;
       int *indx = spx->indx;
       int p = spx->p;
@@ -1520,9 +1517,9 @@ int spx_change_basis(SPX *spx)
       {  /* the special case: xN[q] goes to its opposite bound */
          xassert(1 <= q && q <= n);
          k = indx[m+q]; /* x[k] = xN[q] */
-         xassert(typx[k] == LPX_DB);
-         xassert(tagx[k] == LPX_NL || tagx[k] == LPX_NU);
-         tagx[k] = (tagx[k] == LPX_NL ? LPX_NU : LPX_NL);
+         xassert(type[k] == GLP_DB);
+         xassert(stat[k] == GLP_NL || stat[k] == GLP_NU);
+         stat[k] = (stat[k] == GLP_NL ? GLP_NU : GLP_NL);
          ret = 0;
       }
       else
@@ -1532,25 +1529,52 @@ int spx_change_basis(SPX *spx)
          /* xN[q] takes the place of xB[p] and vice versa */
          kp = indx[p];   /* x[kp] = xB[p] */
          kq = indx[m+q]; /* x[kq] = xN[q] */
-         tagx[kp] = p_tag,  posx[kp] = m+q, indx[m+q] = kp;
-         tagx[kq] = LPX_BS, posx[kq] = p,   indx[p]   = kq;
+         stat[kp] = p_tag,  posx[kp] = m+q, indx[m+q] = kp;
+         stat[kq] = GLP_BS, posx[kq] = p,   indx[p]   = kq;
          /* check the tag of xN[q] (former xB[p]) */
-         switch (typx[kp])
-         {  case LPX_FR:
-               xassert(p_tag == LPX_NF); break;
-            case LPX_LO:
-               xassert(p_tag == LPX_NL); break;
-            case LPX_UP:
-               xassert(p_tag == LPX_NU); break;
-            case LPX_DB:
-               xassert(p_tag == LPX_NL || p_tag == LPX_NU); break;
-            case LPX_FX:
-               xassert(p_tag == LPX_NS); break;
+         switch (type[kp])
+         {  case GLP_FR:
+               xassert(p_tag == GLP_NF); break;
+            case GLP_LO:
+               xassert(p_tag == GLP_NL); break;
+            case GLP_UP:
+               xassert(p_tag == GLP_NU); break;
+            case GLP_DB:
+               xassert(p_tag == GLP_NL || p_tag == GLP_NU); break;
+            case GLP_FX:
+               xassert(p_tag == GLP_NS); break;
             default:
-               xassert(typx != typx);
+               xassert(type != type);
          }
          /* update the factorization of the basis matrix */
+#if 0 /* 02/VI-2007 */
          ret = spx_update(spx, p);
+#else
+         {  int *AT_ptr = spx->AT_ptr;
+            int *AT_ind = spx->AT_ind;
+            double *AT_val = spx->AT_val;
+            double *col = spx->col;
+            int i, ptr, beg, end, len, *ind, _ind[1+1];
+            xassert(1 <= kq && kq <= m+n);
+            for (i = 1; i <= m; i++) col[i] = 0.0;
+            if (kq <= m)
+            {  len = 1;
+               ind = _ind;
+               ind[1] = kq;
+               col[1] = 1.0;
+            }
+            else
+            {  len = 0;
+               beg = AT_ptr[kq-m];
+               end = AT_ptr[kq-m+1];
+               ind = &AT_ind[beg-1];
+               for (ptr = beg; ptr < end; ptr++)
+                  col[++len] = - AT_val[ptr];
+            }
+            xassert(spx->valid);
+            ret = bfd_update_it(spx->bfd, p, kq, len, ind, col);
+         }
+#endif
       }
       /* one simplex iteration has been performed */
       if (spx->it_lim > 0) spx->it_lim--;
@@ -1654,7 +1678,7 @@ double spx_err_in_pi(SPX *spx)
 double spx_err_in_cbar(SPX *spx, int all)
 {     int m = spx->m;
       int n = spx->n;
-      int *tagx = spx->tagx;
+      int *stat = spx->stat;
       int *indx = spx->indx;
       double *cbar = spx->cbar;
       int j, k;
@@ -1665,7 +1689,7 @@ double spx_err_in_cbar(SPX *spx, int all)
       for (j = 1; j <= n; j++)
       {  if (!all)
          {  k = indx[m+j]; /* x[k] = xN[j] */
-            if (tagx[k] == LPX_NS) continue;
+            if (stat[k] == GLP_NS) continue;
          }
          d = fabs(spx->cbar[j] - cbar[j]);
          if (dmax < d) dmax = d;
@@ -1696,7 +1720,7 @@ double spx_err_in_cbar(SPX *spx, int all)
 void spx_reset_refsp(SPX *spx)
 {     int m = spx->m;
       int n = spx->n;
-      int *tagx = spx->tagx;
+      int *stat = spx->stat;
       double *gvec = spx->gvec;
       double *dvec = spx->dvec;
       int *refsp = spx->refsp;
@@ -1705,13 +1729,13 @@ void spx_reset_refsp(SPX *spx)
       {  case 'P':
             /* primal simplex is used */
             for (k = 1; k <= m+n; k++)
-               refsp[k] = (tagx[k] == LPX_BS ? 0 : 1);
+               refsp[k] = (stat[k] == GLP_BS ? 0 : 1);
             for (j = 1; j <= n; j++) gvec[j] = 1.0;
             break;
          case 'D':
             /* dual simplex is used */
             for (k = 1; k <= m+n; k++)
-               refsp[k] = (tagx[k] == LPX_BS ? 1 : 0);
+               refsp[k] = (stat[k] == GLP_BS ? 1 : 0);
             for (i = 1; i <= m; i++) dvec[i] = 1.0;
             break;
          default:
@@ -1746,7 +1770,7 @@ void spx_update_gvec(SPX *spx)
       int *AT_ptr = spx->AT_ptr;
       int *AT_ind = spx->AT_ind;
       double *AT_val = spx->AT_val;
-      int *tagx = spx->tagx;
+      int *stat = spx->stat;
       int *indx = spx->indx;
       int p = spx->p;
       int q = spx->q;
@@ -1791,7 +1815,7 @@ void spx_update_gvec(SPX *spx)
          /* if xN[j] is fixed variable, its weight is not used, because
             fixed variables never enter the basis */
          k = indx[m+j]; /* x[k] = xN[j] */
-         if (tagx[k] == LPX_NS)
+         if (stat[k] == GLP_NS)
          {  gvec[j] = 1.0;
             continue;
          }
@@ -1877,8 +1901,8 @@ double spx_err_in_gvec(SPX *spx)
       {  /* if xN[j] is fixed variable, skip it, because its weight is
             not updated */
          k = indx[m+j];
-         if (spx->typx[k] == LPX_FX)
-         {  xassert(spx->tagx[k] == LPX_NS);
+         if (spx->type[k] == GLP_FX)
+         {  xassert(spx->stat[k] == GLP_NS);
             continue;
          }
          /* compute exact value of gvec[j] */
@@ -1913,7 +1937,7 @@ double spx_err_in_gvec(SPX *spx)
 void spx_update_dvec(SPX *spx)
 {     int m = spx->m;
       int n = spx->n;
-      int *typx = spx->typx;
+      int *type = spx->type;
       int *AT_ptr = spx->AT_ptr;
       int *AT_ind = spx->AT_ind;
       double *AT_val = spx->AT_val;
@@ -1966,7 +1990,7 @@ void spx_update_dvec(SPX *spx)
             }
          }
       }
-      spx_ftran(spx, w, 0);
+      spx_ftran(spx, w);
       /* update the vector delta */
       ref_p = refsp[indx[p]];    /* if xB[p] belongs to the space */
       ref_q = refsp[indx[m+q]];  /* if xN[q] belongs to the space */
@@ -1978,7 +2002,7 @@ void spx_update_dvec(SPX *spx)
          /* if xB[i] is free variable, its weight is not used, because
             free variables never leave the basis */
          k = indx[i];
-         if (typx[k] == LPX_FR)
+         if (type[k] == GLP_FR)
          {  dvec[i] = 1.0;
             continue;
          }
@@ -2041,7 +2065,7 @@ done: return;
 double spx_err_in_dvec(SPX *spx)
 {     int m = spx->m;
       int n = spx->n;
-      int *typx = spx->typx;
+      int *type = spx->type;
       int *indx = spx->indx;
       double *dvec = spx->dvec;
       int *refsp = spx->refsp;
@@ -2054,7 +2078,7 @@ double spx_err_in_dvec(SPX *spx)
       {  /* if xB[i] is free variable, skip it, because its weight is
             not updated */
          k = indx[i];
-         if (typx[k] == LPX_FR) continue;
+         if (type[k] == GLP_FR) continue;
          /* compute exact value of dvec[i] */
          spx_eval_rho(spx, i, rho);
          spx_eval_row(spx, rho, ai);
